var iframe = jQuery('<iframe frameborder="0" marginwidth="0" marginheight="0" allowfullscreen></iframe>');
var dialog;

const toggleServicePoint = function () {
	var data = jQuery('#dhl24-review-data').data();
	if( undefined !== data ) {
		var shippingMethod = data.shippingMethod || '';

		if ( 'dhl24_service_lm' === shippingMethod || 'dhl24_service_sp' === shippingMethod ) {
			jQuery( '#dhl24_sap' ).val( data.sap );
			jQuery( '#dhl24-parcel-address' ).html( data.address );
			jQuery( '#dhl24-shipping-sap' ).show();
		} else {
			jQuery( '#dhl24-shipping-sap' ).hide();
			jQuery( '#dhl24_sap' ).val( '' );
			jQuery( '#dhl24-parcel-address' ).html( '' );
		}
	}
}

const onClickFindServicePoint = function () {
	var country;
	if (jQuery('#ship-to-different-address-checkbox').is(':checked')) {
		country = jQuery('#shipping_country').val() || 'PL';
	} else {
		country = jQuery('#billing_country').val() || 'PL';
	}

	var type = '';
	if (jQuery('#payment_method_cod').is(':checked')) {
		type = '&type=lmcod';
	}

	var src = 'https://parcelshop.dhl.pl/mapa?country=' + country + type;
	var title = 'Wyszukiwarka punktów serwisowych - DHL Parcelshop Manager';
	iframe.attr({
		width: 900,
		height: 700,
		allow: 'geolocation',
		src: src
	});
	dialog.dialog("option", "title", title).dialog("open");

	if (window.addEventListener) {
		window.addEventListener("message", listenMessage, false);
	} else {
		window.attachEvent("onmessage", listenMessage);
	}
}

const validPoint = function (point) {
	var properties = ['sap', 'name', 'zip', 'city', 'street', 'streetNo', 'houseNo'];
	for (const property of properties) {
		if (false === point.hasOwnProperty(property)) {
			return false;
		}
		if (true === /<(|\/|[^\/>][^>]+|\/[^>][^>]+)>/g.test(point[property])) {
			return false;
		}
	}
	return true;
}

const listenMessage = function (msg) {
	if( 'https://parcelshop.dhl.pl' === msg.origin ) {
		if ( 'object' === jQuery.type( msg.data ) ) {
			var point = msg.data;
		} else {
			var point = JSON.parse( msg.data );
		}

		if ( false === validPoint( point ) ) {
			dialog.dialog( 'close' );
			alert( 'Błąd walidacji punktu odbioru.' );
			return;
		}

		jQuery( '#dhl24-shipping-sap input[name^="dhl24_sap"]' ).val( point.sap );
		var address = '<strong>' + point.name + '</strong><br />' + point.zip + ' ' + point.city + '<br />' + point.street + point.streetNo;
		if ( '' !== point.houseNo ) {
			address += '/' + point.houseNo
		}
		jQuery( '#dhl24-parcel-address' ).html( address );
		dialog.dialog( 'close' );
	}
}

jQuery(document).ready(function ($) {
	toggleServicePoint();

	dialog = $("<div></div>").append(iframe).appendTo("body").dialog({
        autoOpen: false,
        modal: true,
        resizable: false,
        width: "auto",
        height: "auto",
        close: function () {
            iframe.attr("src", "");
        }
    });

	jQuery('.btn-find-service-point').on('click', onClickFindServicePoint);


	jQuery( document.body ).on( 'updated_checkout', function() {
		toggleServicePoint();
	});
});
