<?php
/**
 * Class Settings.
 *
 * @package ILabs\WoocommerceDHL24
 */

namespace ILabs\WoocommerceDHL24\Controller;

use ILabs\WoocommerceDHL24\PluginOptions;
use ILabs\WoocommerceDHL24\Helper\WooCommerceSettingsDHL24;

/**
 * Settings
 */
class SettingsController implements ControllerInterface {
	/**
	 * Plugin options
	 *
	 * @var PluginOptions Plugin options.
	 */
	private $plugin_options;

	/**
	 * Setting page id.
	 *
	 * @var string
	 */
	private $id = 'dhl24';

	/**
	 * Construct
	 *
	 * @param PluginOptions $plugin_options Plugin options.
	 * @return void
	 */
	public function __construct( PluginOptions $plugin_options ) {
		$this->plugin_options = $plugin_options;
	}

	/**
	 * Init class.
	 */
	public function init() {
		add_filter( 'plugin_action_links_' . plugin_basename( $this->plugin_options->get_plugin_file() ), array( $this, 'plugin_action_links' ) );
		add_filter( 'plugin_row_meta', array( $this, 'plugin_row_meta' ), 10, 4 );
		add_filter( 'woocommerce_get_settings_pages', array( $this, 'woocommerce_get_settings_pages' ) );
	}

	/**
	 * The woocommerce_get_settings_pages callback.
	 *
	 * @param  array $settings Array of settings.
	 * @return array
	 */
	public function woocommerce_get_settings_pages( array $settings ): array {
		$settings[] = new WooCommerceSettingsDHL24( $this->id );

		return $settings;
	}

	/**
	 * Show action links on the plugin screen.
	 *
	 * @param mixed $links Plugin Action links.
	 *
	 * @return array
	 */
	public function plugin_action_links( $links ) {
		$action_links = array(
			'settings' => '<a href="' . admin_url( 'admin.php?page=wc-settings&tab=' . $this->id ) . '" aria-label="' . esc_attr__( 'View DHL24 for Woocommerce settings', 'woocommerce-dhl24' ) . '">' . esc_html__( 'Settings', 'woocommerce-dhl24' ) . '</a>',
		);

		return array_merge( $action_links, $links );
	}

	/**
	 * Filters the array of row meta for each/specific plugin in the Plugins list table.
	 * Appends additional links below each/specific plugin on the plugins page.
	 *
	 * @param  array  $plugin_meta An array of the plugin's metadata.
	 * @param  string $plugin_file Path to the plugin file.
	 * @param  array  $plugin_data An array of plugin data.
	 * @param  string $status      Status of the plugin.
	 * @return array  $plugin_meta
	 */
	public function plugin_row_meta( $plugin_meta, $plugin_file, $plugin_data, $status ) {
		if ( strpos( $plugin_file, basename( $this->plugin_options->get_plugin_file() ) ) ) {
			$plugin_meta[] = '<a href="https://dhl24.com.pl/pl/pomoc-techniczna/bledy.html#contact">' . esc_html__( 'Help', 'woocommerce-dhl24' ) . '</a>';
			$plugin_meta[] = '<a target="_blank" href="https://narzedzia.dhl.pl/files/integracje/woocommerce/Instrukcja_Woocommerce_DHL.pdf">' . esc_html__( 'Installation manual', 'woocommerce-dhl24' ) . '</a>';
		}

		return $plugin_meta;
	}
}
