<?php
/**
 * Class DeleteShipment
 *
 * @package ILabs\WoocommerceDHL24
 */

namespace ILabs\WoocommerceDHL24\DHL24Client\ServicePoint\Method;

use ILabs\WoocommerceDHL24\DHL24Client\RequestInterface;
use ILabs\WoocommerceDHL24\DHL24Client\ServicePoint\Type\AuthData;

/**
 * DeleteShipment
 */
class DeleteShipment extends AbstractMethod implements RequestInterface {
	/**
	 * Shipment number of the shipment to be deleted.
	 *
	 * @var string
	 */
	private $shipment;

	/**
	 * Constructor
	 *
	 * @param AuthData $authData Authorization data.
	 */
	public function __construct( AuthData $authData ) {
		parent::__construct( $authData );

		$this->shipment = '';
	}

	/**
	 * Return associative array.
	 *
	 * @return array
	 */
	public function toArray(): array {
		return array(
			'shipment' => array_merge(
				parent::toArray(),
				array(
					'shipment' => $this->getShipment(),
				)
			),
		);
	}

	/**
	 * Get shipment number of the shipment to be deleted.
	 *
	 * @return string
	 */
	public function getShipment() {
		return $this->shipment;
	}

	/**
	 * Set shipment number of the shipment to be deleted.
	 *
	 * @param string $shipment Shipment number of the shipment to be deleted.
	 *
	 * @return self
	 */
	public function setShipment( string $shipment ) {
		$this->shipment = $shipment;

		return $this;
	}
}
