<?php
/**
 * Class GetLabel
 *
 * @package ILabs\WoocommerceDHL24
 */

namespace ILabs\WoocommerceDHL24\DHL24Client\ServicePoint\Method;

use ILabs\WoocommerceDHL24\DHL24Client\RequestInterface;
use ILabs\WoocommerceDHL24\DHL24Client\ServicePoint\Type\AuthData;
use ILabs\WoocommerceDHL24\DHL24Client\ServicePoint\Type\ItemToPrint;

/**
 * GetLabel
 */
class GetLabel extends AbstractMethod implements RequestInterface {
	/**
	 * Shipment number of the shipment to be deleted.
	 *
	 * @var string
	 */
	private $shipment;

	/**
	 * Label type.
	 * BLP or ZBLP
	 *
	 * @var string
	 */
	private $type;


	/**
	 * Constructor
	 *
	 * @param AuthData $authData Authorization data.
	 */
	public function __construct( AuthData $authData ) {
		parent::__construct( $authData );

		$this->shipment = '';
		$this->type     = 'BLP';
	}

	/**
	 * Return associative array.
	 *
	 * @return array
	 */
	public function toArray(): array {
		return array(
			'structure' => array_merge(
				parent::toArray(),
				array(
					'shipment' => $this->getShipment(),
					'type'     => $this->getType(),
				)
			),
		);
	}

	/**
	 * Get shipment number of the shipment to be deleted.
	 *
	 * @return string
	 */
	public function getShipment() {
		return $this->shipment;
	}

	/**
	 * Set shipment number of the shipment to be deleted.
	 *
	 * @param string $shipment Shipment number of the shipment to be deleted.
	 *
	 * @return self
	 */
	public function setShipment( string $shipment ) {
		$this->shipment = $shipment;

		return $this;
	}

	/**
	 * Get label type.
	 *
	 * @return  string
	 */
	public function getType() {
		return $this->type;
	}

	/**
	 * Set label type.
	 *
	 * @param  string $type  Label type.
	 *
	 * @return  self
	 */
	public function setType( string $type ) {
		$this->type = $type;

		return $this;
	}
}
