<?php
/**
 * Class GetNearestTerminalServicepoints
 *
 * @package ILabs\WoocommerceDHL24
 */

namespace ILabs\WoocommerceDHL24\DHL24Client\ServicePoint\Method;

use ILabs\WoocommerceDHL24\DHL24Client\RequestInterface;
use ILabs\WoocommerceDHL24\DHL24Client\ServicePoint\Type\AuthData;

/**
 * GetNearestTerminalServicepoints
 */
class GetNearestTerminalServicepoints extends AbstractMethod implements RequestInterface {


	/**
	 * Postal code, without dash.
	 *
	 * @var string
	 */
	private $postcode;

	/**
	 * City name.
	 *
	 * @var string
	 */
	private $city;

	/**
	 * Radius in km.
	 *
	 * @var int
	 */
	private $radius;

	/**
	 * ToForeignPs.
	 *
	 * @var bool|true
	 */
	private $toForeignPs;

	/**
	 * ToPm.
	 *
	 * @var bool|true
	 */
	private $toPm;

	/**
	 * WithCOD.
	 *
	 * @var bool|true
	 */
	private $withCOD;

	/**
	 * Limit.
	 *
	 * @var int|true
	 */
	private $limit;


	/**
	 * Constructor
	 *
	 * @param AuthData $authData Authorization data.
	 */
	public function __construct( AuthData $authData ) {
		parent::__construct( $authData );

		$this->postcode = '';
		$this->city     = '';
		$this->radius   = 0;
	}

	/**
	 * Return associative array.
	 *
	 * @return array
	 */
	public function toArray(): array {
		return array(
			'structure' => array_merge(
				parent::toArray(),
				array(
					'postcode'    => $this->getPostcode(),
					'city'        => $this->getCity(),
					'radius'      => $this->getRadius(),
					'toForeignPs' => $this->getToForeignPs(),
					'toPm'        => $this->getToPm(),
					'withCOD'     => $this->getWithCOD(),
					'limit'       => $this->getLimit(),
				)
			),
		);
	}

	/**
	 * Get postal code, without dash.
	 *
	 * @return  string
	 */
	public function getPostcode() {
		return $this->postcode;
	}

	/**
	 * Set postal code, without dash.
	 *
	 * @param  string $postcode  Postal code, without dash.
	 *
	 * @return  self
	 */
	public function setPostcode( string $postcode ) {
		$this->postcode = $postcode;

		return $this;
	}

	/**
	 * Get city name.
	 *
	 * @return  string
	 */
	public function getCity() {
		return $this->city;
	}

	/**
	 * Set city name.
	 *
	 * @param  string $city  City name.
	 *
	 * @return  self
	 */
	public function setCity( string $city ) {
		$this->city = $city;

		return $this;
	}

	/**
	 * Get radius in km.
	 *
	 * @return  int
	 */
	public function getRadius() {
		return $this->radius;
	}

	/**
	 * Set radius in km.
	 *
	 * @param  int $radius  Radius in km.
	 *
	 * @return  self
	 */
	public function setRadius( int $radius ) {
		$this->radius = $radius;

		return $this;
	}

	/**
	 * Get toForeignPs.
	 *
	 * @return  bool|true
	 */
	public function getToForeignPs() {
		return $this->toForeignPs;
	}

	/**
	 * Set toForeignPs.
	 *
	 * @param  bool|true $toForeignPs  ToForeignPs.
	 *
	 * @return  self
	 */
	public function setToForeignPs( $toForeignPs ) {
		$this->toForeignPs = $toForeignPs;

		return $this;
	}

	/**
	 * Get toPm.
	 *
	 * @return  bool|true
	 */
	public function getToPm() {
		return $this->toPm;
	}

	/**
	 * Set toPm.
	 *
	 * @param  bool|true $toPm  ToPm.
	 *
	 * @return  self
	 */
	public function setToPm( $toPm ) {
		$this->toPm = $toPm;

		return $this;
	}

	/**
	 * Get withCOD.
	 *
	 * @return  bool|true
	 */
	public function getWithCOD() {
		return $this->withCOD;
	}

	/**
	 * Set withCOD.
	 *
	 * @param  bool|true $withCOD  WithCOD.
	 *
	 * @return  self
	 */
	public function setWithCOD( $withCOD ) {
		$this->withCOD = $withCOD;

		return $this;
	}

	/**
	 * Get limit.
	 *
	 * @return  int|true
	 */
	public function getLimit() {
		return $this->limit;
	}

	/**
	 * Set limit.
	 *
	 * @param  int|true $limit  Limit.
	 *
	 * @return  self
	 */
	public function setLimit( $limit ) {
		$this->limit = $limit;

		return $this;
	}
}
