<?php
/**
 * Class ServicePointClient
 *
 * @package ILabs\WoocommerceDHL24
 */

namespace ILabs\WoocommerceDHL24\DHL24Client\ServicePoint;

use InvalidArgumentException;
use ILabs\WoocommerceDHL24\DHL24Client\SoapClient;
use ILabs\WoocommerceDHL24\DHL24Client\ServicePoint\Method;
use ILabs\WoocommerceDHL24\DHL24Client\ServicePoint\Type;
use ILabs\WoocommerceDHL24\DHL24Client\ResultInterface;
use ILabs\WoocommerceDHL24\DHL24Client\ServicePoint\Convert\ConvertInterface;
use ILabs\WoocommerceDHL24\DHL24Client\ServicePoint\Convert\ConvertContext;

/**
 * ServicePointClient
 */
class ServicePointClient extends SoapClient {

	/**
	 * Return Shipment.
	 *
	 * @param Method\CreateShipment $parameters Function parameters.
	 * @return Type\Shipment
	 * @throws \Exception If error.
	 */
	public function createShipment( Method\CreateShipment $parameters ) : Type\Shipment {
		$this->method = 'createShipment';
		return $this->call( $parameters );
	}

	/**
	 * Return DeleteShipment.
	 *
	 * @param Method\DeleteShipment $parameters Function parameters.
	 * @return Type\DeleteShipment
	 * @throws \Exception If error.
	 */
	public function deleteShipment( Method\DeleteShipment $parameters ) : Type\DeleteShipment {
		$this->method = 'deleteShipment';
		return $this->call( $parameters );
	}

	/**
	 * Return Label.
	 *
	 * @param Method\GetLabel $parameters Function parameters.
	 * @return Type\Label
	 * @throws \Exception If error.
	 */
	public function getLabel( Method\GetLabel $parameters ) : Type\Label {
		$this->method = 'getLabel';
		return $this->call( $parameters );
	}

	/**
	 * Return Pnp.
	 *
	 * @param Method\GetPnp $parameters Function parameters.
	 * @return Type\Label
	 * @throws \Exception If error.
	 */
	public function getPnp( Method\GetPnp $parameters ) : Type\Label {
		$this->method = 'getPnp';
		return $this->call( $parameters );
	}

	/**
	 * Return NearestServicepoints.
	 *
	 * @param Method\GetNearestServicepoints $parameters Function parameters.
	 * @return Type\NearestServicepoints
	 * @throws \Exception If error.
	 */
	public function getNearestServicepoints( Method\GetNearestServicepoints $parameters ) : Type\NearestServicepoints {
		$this->method = 'getNearestServicepoints';
		return $this->call( $parameters );
	}

	/**
	 * Return NearestServicepoints.
	 *
	 * @param Method\GetNearestTerminalServicepoints $parameters Function parameters.
	 * @return Type\TerminalPoints
	 * @throws \Exception If error.
	 */
	public function getNearestTerminalServicepoints( Method\GetNearestTerminalServicepoints $parameters ) : Type\TerminalPoints {
		$this->method = 'getNearestTerminalServicepoints';
		return $this->call( $parameters );
	}

	/**
	 * Return NearestServicepoints.
	 *
	 * @param Method\GetNearestServicepointsCOD $parameters Function parameters.
	 * @return Type\NearestServicepoints
	 * @throws \Exception If error.
	 */
	public function getNearestServicepointsCOD( Method\GetNearestServicepointsCOD $parameters ) : Type\NearestServicepoints {
		$this->method = 'getNearestServicepointsCOD';
		return $this->call( $parameters );
	}

	/**
	 * { @inheritDoc }
	 *
	 * @param \stdClass $sourceObject Source object.
	 *
	 * @return ResultInterface Result.
	 */
	protected function cast( \stdClass $sourceObject ): ResultInterface {
		$context = new ConvertContext();
		$context->setStrategy( $this->getStrategy() );
		return $context->cast( $sourceObject );
	}

	/**
	 * Get strategy.
	 *
	 * @throws \InvalidArgumentException If error.
	 * @return ConvertInterface
	 */
	private function getStrategy() : ConvertInterface {
		$strategyClassName = __NAMESPACE__ . '\\Convert\\Convert' . \ucfirst( $this->method );
		try {
			return new $strategyClassName();
		} catch ( \Exception $e ) {
			throw new \InvalidArgumentException();
		}
	}
}
