<?php
/**
 * Class Billing
 *
 * @package ILabs\WoocommerceDHL24
 */

namespace ILabs\WoocommerceDHL24\DHL24Client\ServicePoint\Type;

/**
 * Billing
 */
class Billing {
	/**
	 * Identification of the party to be charged, possible options:
	 * SHIPPER - shipper,
	 * USER - third party
	 *
	 * @var string|null
	 */
	private $shippingPaymentType;

	/**
	 * Customer SAP number to be charged.
	 *
	 * @var int|null
	 */
	private $billingAccountNumber;

	/**
	 * Payment method selection, possible values:
	 * BANK_TRANSFER - bank transfer
	 *
	 * @var string|null
	 */
	private $paymentType;

	/**
	 * Cost centre.
	 *
	 * @var string|null
	 */
	private $costsCenter;

	/**
	 * Return associative array.
	 *
	 * @return array
	 */
	public function toArray(): array {
		return array(
			'shippingPaymentType'  => $this->getShippingPaymentType(),
			'billingAccountNumber' => $this->getBillingAccountNumber(),
			'paymentType'          => $this->getPaymentType(),
			'costsCenter'          => $this->getCostsCenter(),
		);
	}

	/**
	 * Get identification of the party to be charged.
	 *
	 * @return string|null
	 */
	public function getShippingPaymentType() {
		return $this->shippingPaymentType;
	}

	/**
	 * Set identification of the party to be charged.
	 *
	 * @param string|null $shippingPaymentType Shipping payment type.
	 *
	 * @return self
	 */
	public function setShippingPaymentType( $shippingPaymentType ) {
		$this->shippingPaymentType = $shippingPaymentType;

		return $this;
	}

	/**
	 * Get customer number to be charged.
	 *
	 * @return int|null
	 */
	public function getBillingAccountNumber() {
		return $this->billingAccountNumber;
	}

	/**
	 * Set customer number to be charged.
	 *
	 * @param int|null $billingAccountNumber Customer number to be charged.
	 *
	 * @return self
	 */
	public function setBillingAccountNumber( $billingAccountNumber ) {
		$this->billingAccountNumber = $billingAccountNumber;

		return $this;
	}

	/**
	 * Get payment method selection.
	 *
	 * @return string|null
	 */
	public function getPaymentType() {
		return $this->paymentType;
	}

	/**
	 * Set payment method selection.
	 *
	 * @param string|null $paymentType Payment method selection.
	 *
	 * @return self
	 */
	public function setPaymentType( $paymentType ) {
		$this->paymentType = $paymentType;

		return $this;
	}

	/**
	 * Get cost centre.
	 *
	 * @return string|null
	 */
	public function getCostsCenter() {
		return $this->costsCenter;
	}

	/**
	 * Set cost centre.
	 *
	 * @param string|null $costsCenter Cost centre.
	 *
	 * @return self
	 */
	public function setCostsCenter( $costsCenter ) {
		$this->costsCenter = $costsCenter;

		return $this;
	}
}
