<?php
/**
 * Class Receiver
 *
 * @package ILabs\WoocommerceDHL24
 */

namespace ILabs\WoocommerceDHL24\DHL24Client\ServicePoint\Type;

/**
 * Receiver
 */
class Receiver {
	/**
	 * Address.
	 *
	 * @var Address|null
	 */
	private $address;

	/**
	 * Pre-delivery contact - details for pre-delivery contact.
	 *
	 * @var Contact|null
	 */
	private $contact;

	/**
	 * Pre-delivery notification details for pre-delivery notification.
	 *
	 * @var Preaviso|null
	 */
	private $preaviso;

	/**
	 * Return associative array.
	 *
	 * @return array
	 */
	public function toArray(): array {
		return array(
			'address'  => $this->getAddress() ? $this->getAddress()->toArray() : null,
			'contact'  => $this->getContact() ? $this->getContact()->toArray() : null,
			'preaviso' => $this->getPreaviso() ? $this->getPreaviso()->toArray() : null,
		);
	}

	/**
	 * Get address.
	 *
	 * @return Address|null
	 */
	public function getAddress() {
		return $this->address;
	}

	/**
	 * Set address.
	 *
	 * @param Address|null $address Address.
	 *
	 * @return self
	 */
	public function setAddress( $address ) {
		$this->address = $address;

		return $this;
	}

	/**
	 * Get pre-delivery contact - details for pre-delivery contact.
	 *
	 * @return PreavisoContact|null
	 */
	public function getContact() {
		return $this->contact;
	}

	/**
	 * Set pre-delivery contact - details for pre-delivery contact.
	 *
	 * @param PreavisoContact|null $contact Pre-delivery contact - details for pre-delivery contact.
	 *
	 * @return self
	 */
	public function setContact( $contact ) {
		$this->contact = $contact;

		return $this;
	}

	/**
	 * Get pre-delivery notification details for pre-delivery notification.
	 *
	 * @return PreavisoContact|null
	 */
	public function getPreaviso() {
		return $this->preaviso;
	}

	/**
	 * Set pre-delivery notification details for pre-delivery notification.
	 *
	 * @param PreavisoContact|null $preaviso Pre-delivery notification details for pre-delivery notification.
	 *
	 * @return self
	 */
	public function setPreaviso( $preaviso ) {
		$this->preaviso = $preaviso;

		return $this;
	}
}
