<?php
/**
 * Class Service
 *
 * @package ILabs\WoocommerceDHL24
 */

namespace ILabs\WoocommerceDHL24\DHL24Client\ServicePoint\Type;

/**
 * Service
 */
class Service {
	/**
	 * Special service type.
	 *
	 * @var string|null
	 */
	private $serviceType;

	/**
	 * Declared value required when ordering the insurance service or the COD service.
	 *
	 * @var float|null
	 */
	private $serviceValue;

	/**
	 * Additional text.
	 *
	 * @var string|null
	 */
	private $textInstruction;

	/**
	 * Form of the collection amount refund in the COD service.
	 *
	 * @var string|null
	 */
	private $collectOnDeliveryForm;

	/**
	 * Return associative array.
	 *
	 * @return array
	 */
	public function toArray(): array {
		return array(
			'serviceType'           => $this->getServiceType(),
			'serviceValue'          => $this->getServiceValue(),
			'textInstruction'       => $this->getTextInstruction(),
			'collectOnDeliveryForm' => $this->getCollectOnDeliveryForm(),
		);
	}


	/**
	 * Get special service type.
	 *
	 * @return string|null
	 */
	public function getServiceType() {
		return $this->serviceType;
	}

	/**
	 * Set special service type.
	 * Possible values:
	 * UBEZP - Shipment Insurance
	 * COD - Cash on Delivery
	 *
	 * @param string|null $serviceType Special service type.
	 *
	 * @return self
	 */
	public function setServiceType( $serviceType ) {
		if ( in_array( $serviceType, array( 'UBEZP', 'COD' ), true ) ) {
			$this->serviceType = $serviceType;
		}

		return $this;
	}

	/**
	 * Get declared value required when ordering the insurance service or the COD service.
	 *
	 * @return float|null
	 */
	public function getServiceValue() {
		return $this->serviceValue;
	}

	/**
	 * Set declared value required when ordering the insurance service or the COD service.
	 *
	 * @param float|null $serviceValue Declared value required when ordering the insurance service or the COD service.
	 *
	 * @return self
	 */
	public function setServiceValue( $serviceValue ) {
		$this->serviceValue = $serviceValue;

		return $this;
	}

	/**
	 * Get additional text.
	 *
	 * @return string|null
	 */
	public function getTextInstruction() {
		return $this->textInstruction;
	}

	/**
	 * Set additional text.
	 *
	 * @param string|null $textInstruction Additional text.
	 *
	 * @return self
	 */
	public function setTextInstruction( $textInstruction ) {
		$this->textInstruction = $textInstruction;

		return $this;
	}

	/**
	 * Get form of the collection amount refund in the COD service.
	 *
	 * @return string|null
	 */
	public function getCollectOnDeliveryForm() {
		return $this->collectOnDeliveryForm;
	}

	/**
	 * Set form of the collection amount refund in the COD service.
	 * Possible values: BANK_TRANSFER - bank transfer (only for customers with an agreement and SAP number)
	 *
	 * @param string|null $collectOnDeliveryForm Form of the collection amount refund in the COD service.
	 *
	 * @return self
	 */
	public function setCollectOnDeliveryForm( $collectOnDeliveryForm ) {
		if ( in_array( $collectOnDeliveryForm, array( 'BANK_TRANSFER' ), true ) ) {
			$this->collectOnDeliveryForm = $collectOnDeliveryForm;
		}

		return $this;
	}
}
