<?php
/**
 * Class Ship
 *
 * @package ILabs\WoocommerceDHL24
 */

namespace ILabs\WoocommerceDHL24\DHL24Client\ServicePoint\Type;

/**
 * Ship
 */
class Ship {
	/**
	 * Address details of the sender.
	 *
	 * @var FullAddress|null
	 */
	private $shipper;

	/**
	 * Address details of the recipient.
	 *
	 * @var Receiver|null
	 */
	private $receiver;

	/**
	 * Service point SAP number, required to download address.
	 *
	 * @var string|null
	 */
	private $servicePointAccountNumber;

	/**
	 * Return associative array.
	 *
	 * @return array
	 */
	public function toArray(): array {
		return array(
			'shipper'                   => $this->getShipper() ? $this->getShipper()->toArray() : null,
			'receiver'                  => $this->getReceiver() ? $this->getReceiver()->toArray() : null,
			'servicePointAccountNumber' => $this->getServicePointAccountNumber(),
		);
	}

	/**
	 * Get address details of the sender.
	 *
	 * @return FullAddress|null
	 */
	public function getShipper() {
		return $this->shipper;
	}

	/**
	 * Set address details of the sender.
	 *
	 * @param FullAddress|null $shipper Address details of the sender.
	 *
	 * @return self
	 */
	public function setShipper( $shipper ) {
		$this->shipper = $shipper;

		return $this;
	}

	/**
	 * Get address details of the recipient.
	 *
	 * @return Receiver|null
	 */
	public function getReceiver() {
		return $this->receiver;
	}

	/**
	 * Set address details of the recipient.
	 *
	 * @param Receiver|null $receiver Address details of the recipient.
	 *
	 * @return self
	 */
	public function setReceiver( $receiver ) {
		$this->receiver = $receiver;

		return $this;
	}

	/**
	 * Get service point SAP number, required to download address.
	 *
	 * @return  string|null
	 */
	public function getServicePointAccountNumber() {
		return $this->servicePointAccountNumber;
	}

	/**
	 * Set service point SAP number, required to download address.
	 *
	 * @param  string|null $servicePointAccountNumber  Service point SAP number, required to download address.
	 *
	 * @return  self
	 */
	public function setServicePointAccountNumber( $servicePointAccountNumber ) {
		$this->servicePointAccountNumber = $servicePointAccountNumber;

		return $this;
	}
}
