<?php
/**
 * Interface SoapClientInterface
 *
 * @package ILabs\WoocommerceDHL24
 */

namespace ILabs\WoocommerceDHL24\DHL24Client;

interface SoapClientInterface {
	/**
	 * Performs a SOAP request.
	 *
	 * @param  string $request The XML SOAP request.
	 * @param  string $location The URL to request.
	 * @param  string $action The SOAP action.
	 * @param  int    $version The SOAP version.
	 * @param  mixed  $one_way If one_way is set to 1, this method returns nothing.
	 *
	 * @throws \Exception If error.
	 *
	 * @return void
	 */
	public function __doRequest( $request, $location, $action, $version, $one_way = false ); // phpcs:ignore

	/**
	 * Set mock requests.
	 *
	 * @param array $mock_requests Mock requests.
	 * @return void
	 */
	public function set_mock_requests( array $mock_requests);

	/**
	 * Set mock responses.
	 *
	 * @param array $mock_responses Mock responses.
	 *
	 * @return void
	 */
	public function set_mock_responses( array $mock_responses);

	/**
	 * Get options.
	 *
	 * @return array
	 */
	public function get_options(): array;
}
