<?php
/**
 * Class ConvertGetPieceId
 *
 * @package ILabs\WoocommerceDHL24
 */

namespace ILabs\WoocommerceDHL24\DHL24Client\WebAPI\Convert;

use ILabs\WoocommerceDHL24\Exception\ConvertException;
use ILabs\WoocommerceDHL24\DHL24Client\ResultInterface;
use ILabs\WoocommerceDHL24\DHL24Client\WebAPI\Type\Pnp;
use ILabs\WoocommerceDHL24\DHL24Client\WebAPI\Type\PieceShipments;

/**
 * ConvertGetPieceId
 */
class ConvertGetPieceId implements ConvertInterface {
	use CastTrait;

	/**
	 * Source object cast.
	 *
	 * @param \stdClass $sourceObject Source object.
	 * @return ResultInterface
	 * @throws ConvertException If error.
	 */
	public function cast( \stdClass $sourceObject ): ResultInterface {
		try {
			$sourceObject = $sourceObject->getPieceIdResult;
		} catch ( \Exception $e ) {
			throw new ConvertException( $e, $e->getMessage() );
		}
		$pieceShipments = new PieceShipments();
		if ( isset( $sourceObject->shipments->item ) ) {
			$items = $sourceObject->shipments->item;
			foreach ( $items as $item ) {
				$pieceShipment = $this->castObject( 'pieceShipment', $item, array( 'packages' => 'piece' ) );
				$pieceShipments->addItem( $pieceShipment );
			};
		}

		return $pieceShipments;
	}
}
