<?php
/**
 * Class CancelCourierBooking
 *
 * @package ILabs\WoocommerceDHL24
 */

namespace ILabs\WoocommerceDHL24\DHL24Client\WebAPI\Method;

use ILabs\WoocommerceDHL24\DHL24Client\RequestInterface;
use ILabs\WoocommerceDHL24\DHL24Client\WebAPI\Type\AuthData;

/**
 * CancelCourierBooking
 */
class CancelCourierBooking extends AbstractMethod implements RequestInterface {

	/**
	 * Array of string-type items containing courier order numbers obtained using the bookCourier method.
	 *
	 * @var \ArrayObject|string[]
	 */
	private $orders;

	/**
	 * Constructor
	 *
	 * @param AuthData $authData Authorization data.
	 */
	public function __construct( AuthData $authData ) {
		parent::__construct( $authData );

		$this->orders = new \ArrayObject();
	}

	/**
	 * Return associative array.
	 *
	 * @return array
	 */
	public function toArray(): array {
		$orders = array();
		foreach ( $this->getOrders() as $key => $value ) {
			$orders[] = $value;
		}
		return array_merge(
			parent::toArray(),
			array(
				'orders' => $orders,
			)
		);
	}

	/**
	 * Get array of string-type items containing courier order numbers obtained using the bookCourier method.
	 *
	 * @return  \ArrayObject|string[]
	 */
	public function getOrders() {
		return $this->orders;
	}

	/**
	 * Add courier order number obtained using the bookCourier method.
	 *
	 * @param string $order Order number.
	 *
	 * @return  self
	 */
	public function addOrder( string $order ) {
		$this->orders->append( $order );

		return $this;
	}

	/**
	 * Remove courier order number obtained using the bookCourier method.
	 *
	 * @param string $order Order number.
	 *
	 * @return  self
	 */
	public function removeOrder( string $order ) {
		// TODO.

		return $this;
	}
}
