<?php
/**
 * Class CreateShipments
 *
 * @package ILabs\WoocommerceDHL24
 */

namespace ILabs\WoocommerceDHL24\DHL24Client\WebAPI\Method;

use ILabs\WoocommerceDHL24\DHL24Client\RequestInterface;
use ILabs\WoocommerceDHL24\DHL24Client\WebAPI\Type\AuthData;
use ILabs\WoocommerceDHL24\DHL24Client\WebAPI\Type\ShipmentFullData;

/**
 * CreateShipments
 */
class CreateShipments extends AbstractMethod implements RequestInterface {

	/**
	 * Array of structures ShipmentFullData.
	 * An array with at least one structure defining the shipment (maximum of three structures).
	 *
	 * @var \ArrayObject|ShipmentFullData[]
	 */
	private $shipments;

	/**
	 * Constructor
	 *
	 * @param AuthData $authData Authorization data.
	 */
	public function __construct( AuthData $authData ) {
		parent::__construct( $authData );

		$this->shipments = new \ArrayObject();
	}

	/**
	 * Return associative array.
	 *
	 * @return array
	 */
	public function toArray(): array {
		$shipments = array();
		foreach ( $this->getShipments() as $key => $value ) {
			$shipments[] = $value->toArray();
		}
		return array_merge(
			parent::toArray(),
			array(
				'shipments' => $shipments,
			)
		);
	}

	/**
	 * Get array of structures ShipmentFullData.
	 *
	 * @return \ArrayObject
	 */
	public function getShipments() {
		return $this->shipments;
	}

	/**
	 * Add the structure ShipmentFullData.
	 *
	 * @param ShipmentFullData $shipment The structure provides full data on the selected shipment.
	 *
	 * @return self
	 */
	public function addShipment( ShipmentFullData $shipment ) {
		$this->shipments->append( $shipment );

		return $this;
	}

	/**
	 * Remove the structure ShipmentFullData.
	 *
	 * @param ShipmentFullData $shipment The structure provides full data on the selected shipment.
	 *
	 * @return self
	 */
	public function removeShipment( ShipmentFullData $shipment ) {
		// TODO.

		return $this;
	}
}
