<?php
/**
 * Class DeleteShipment
 *
 * @package ILabs\WoocommerceDHL24
 */

namespace ILabs\WoocommerceDHL24\DHL24Client\WebAPI\Method;

use ILabs\WoocommerceDHL24\DHL24Client\RequestInterface;
use ILabs\WoocommerceDHL24\DHL24Client\WebAPI\Type\AuthData;

/**
 * DeleteShipment
 */
class DeleteShipment extends AbstractMethod implements RequestInterface {
	/**
	 * Shipment number of the shipment to be deleted.
	 *
	 * @var string
	 */
	private $shipmentIdentificationNumber;

	/**
	 * ID of the courier order to be cancelled.
	 *
	 * @var string
	 */
	private $dispatchIdentificationNumber;

	/**
	 * Constructor
	 *
	 * @param AuthData $authData Authorization data.
	 */
	public function __construct( AuthData $authData ) {
		parent::__construct( $authData );

		$this->shipmentIdentificationNumber = '';
		$this->dispatchIdentificationNumber = '';
	}

	/**
	 * Return associative array.
	 *
	 * @return array
	 */
	public function toArray(): array {
		return array_merge(
			parent::toArray(),
			array(
				'shipment' => array(
					'shipmentIdentificationNumber' => $this->getShipmentIdentificationNumber(),
					'dispatchIdentificationNumber' => $this->getDispatchIdentificationNumber(),
				),
			)
		);
	}

	/**
	 * Get shipment number of the shipment to be deleted.
	 *
	 * @return string
	 */
	public function getShipmentIdentificationNumber() {
		return $this->shipmentIdentificationNumber;
	}

	/**
	 * Set shipment number of the shipment to be deleted.
	 *
	 * @param string $shipmentIdentificationNumber Shipment number of the shipment to be deleted.
	 *
	 * @return self
	 */
	public function setShipmentIdentificationNumber( string $shipmentIdentificationNumber ) {
		$this->shipmentIdentificationNumber = $shipmentIdentificationNumber;

		return $this;
	}

	/**
	 * Get iD of the courier order to be cancelled.
	 *
	 * @return string
	 */
	public function getDispatchIdentificationNumber() {
		return $this->dispatchIdentificationNumber;
	}

	/**
	 * Set iD of the courier order to be cancelled.
	 *
	 * @param string $dispatchIdentificationNumber ID of the courier order to be cancelled.
	 *
	 * @return self
	 */
	public function setDispatchIdentificationNumber( string $dispatchIdentificationNumber ) {
		$this->dispatchIdentificationNumber = $dispatchIdentificationNumber;

		return $this;
	}
}
