<?php
/**
 * Class DeleteShipments
 *
 * @package ILabs\WoocommerceDHL24
 */

namespace ILabs\WoocommerceDHL24\DHL24Client\WebAPI\Method;

use ILabs\WoocommerceDHL24\DHL24Client\RequestInterface;
use ILabs\WoocommerceDHL24\DHL24Client\WebAPI\Type\AuthData;

/**
 * DeleteShipments
 */
class DeleteShipments extends AbstractMethod implements RequestInterface {
	/**
	 * Array of text-based shipment IDs.
	 *
	 * @var \ArrayObject|string[]
	 */
	private $shipments;

	/**
	 * Constructor
	 *
	 * @param AuthData $authData Authorization data.
	 */
	public function __construct( AuthData $authData ) {
		parent::__construct( $authData );

		$this->shipments = new \ArrayObject();
	}

	/**
	 * Return associative array.
	 *
	 * @return array
	 */
	public function toArray(): array {
		$shipments = array();
		foreach ( $this->getShipments() as $key => $value ) {
			$shipments[] = $value;
		}
		return array_merge(
			parent::toArray(),
			array(
				'shipments' => $shipments,
			)
		);
	}

	/**
	 * Get array of text-based shipment IDs.
	 *
	 * @return  \ArrayObject|string[]
	 */
	public function getShipments() {
		return $this->shipments;
	}

	/**
	 * Add shipment ID.
	 *
	 * @param string $shipment Shipment number.
	 *
	 * @return  self
	 */
	public function addShipment( string $shipment ) {
		$this->shipments->append( $shipment );

		return $this;
	}

	/**
	 * Remove shipment ID.
	 *
	 * @param string $shipment Shipment number.
	 *
	 * @return  self
	 */
	public function removeShipment( string $shipment ) {
		// TODO.

		return $this;
	}
}
