<?php
/**
 * Class GetLabels
 *
 * @package ILabs\WoocommerceDHL24
 */

namespace ILabs\WoocommerceDHL24\DHL24Client\WebAPI\Method;

use ILabs\WoocommerceDHL24\DHL24Client\RequestInterface;
use ILabs\WoocommerceDHL24\DHL24Client\WebAPI\Type\AuthData;
use ILabs\WoocommerceDHL24\DHL24Client\WebAPI\Type\ItemToPrint;

/**
 * GetLabels
 */
class GetLabels extends AbstractMethod implements RequestInterface {
	/**
	 * Array of itemsToPrint type structures.
	 *
	 * @var \ArrayObject|ItemToPrint[]
	 */
	private $itemsToPrint;

	/**
	 * Constructor
	 *
	 * @param AuthData $authData Authorization data.
	 */
	public function __construct( AuthData $authData ) {
		parent::__construct( $authData );

		$this->itemsToPrint = new \ArrayObject();
	}

	/**
	 * Return associative array.
	 *
	 * @return array
	 */
	public function toArray(): array {
		$itemsToPrint = array();
		foreach ( $this->getItemsToPrint() as $key => $value ) {
			$itemsToPrint[] = $value->toArray();
		}
		return array_merge(
			parent::toArray(),
			array(
				'itemsToPrint' => $itemsToPrint,
			)
		);
	}

	/**
	 * Get array of itemsToPrint type structures.
	 *
	 * @return \ArrayObject|ItemToPrint[]
	 */
	public function getItemsToPrint() {
		return $this->itemsToPrint;
	}

	/**
	 * Add itemToPrint.
	 *
	 * @param ItemToPrint $itemToPrint ItemToPrint.
	 *
	 * @return self
	 */
	public function addItemToPrint( ItemToPrint $itemToPrint ) {
		$this->itemsToPrint->append( $itemToPrint );

		return $this;
	}

	/**
	 * Remove itemToPrint.
	 *
	 * @param ItemToPrint $itemToPrint ItemToPrint.
	 *
	 * @return self
	 */
	public function removeItemToPrint( ItemToPrint $itemToPrint ) {
		// TODO.

		return $this;
	}
}
