<?php
/**
 * Class GetMyShipmentsCount
 *
 * @package ILabs\WoocommerceDHL24
 */

namespace ILabs\WoocommerceDHL24\DHL24Client\WebAPI\Method;

use ILabs\WoocommerceDHL24\DHL24Client\RequestInterface;
use ILabs\WoocommerceDHL24\DHL24Client\WebAPI\Type\AuthData;

/**
 * GetMyShipmentsCount
 */
class GetMyShipmentsCount extends AbstractMethod implements RequestInterface {

	/**
	 * Start of time range.
	 *
	 * @var \DateTime
	 */
	private $createdFrom;

	/**
	 * End of time range.
	 *
	 * @var \DateTime
	 */
	private $createdTo;

	/**
	 * Constructor
	 *
	 * @param AuthData $authData Authorization data.
	 */
	public function __construct( AuthData $authData ) {
		parent::__construct( $authData );

		$this->createdTo = new \DateTime();
		// Nieprawidłowy zakres dat - poprawny zakres nie może przekroczyć 90 dni.
		$this->createdFrom = new \DateTime();
		$this->createdFrom->sub( new \DateInterval( 'P89D' ) );
	}

	/**
	 * Return associative array.
	 *
	 * @return array
	 */
	public function toArray(): array {
		return array_merge(
			parent::toArray(),
			array(
				'createdFrom' => $this->getCreatedFrom()->format( 'Y-m-d' ), // Date in YYYY-MM-DD format.
				'createdTo'   => $this->getCreatedTo()->format( 'Y-m-d' ), // Date in YYYY-MM-DD format.
			)
		);
	}

	/**
	 * Get start of time range.
	 *
	 * @return \DateTime
	 */
	public function getCreatedFrom() {
		return $this->createdFrom;
	}

	/**
	 * Set start of time range.
	 *
	 * @param  \DateTime $createdFrom  Start of time range.
	 *
	 * @return  self
	 */
	public function setCreatedFrom( \DateTime $createdFrom ) {
		$this->createdFrom = $createdFrom;

		return $this;
	}

	/**
	 * Get end of time range.
	 *
	 * @return \DateTime
	 */
	public function getCreatedTo(): \DateTime {
		return $this->createdTo;
	}

	/**
	 * Set end of time range.
	 *
	 * @param  \DateTime $createdTo  End of time range.
	 *
	 * @return  self
	 */
	public function setCreatedTo( \DateTime $createdTo ) {
		$this->createdTo = $createdTo;

		return $this;
	}
}
