<?php
/**
 * Class GetPnp
 *
 * @package ILabs\WoocommerceDHL24
 */

namespace ILabs\WoocommerceDHL24\DHL24Client\WebAPI\Method;

use ILabs\WoocommerceDHL24\DHL24Client\RequestInterface;
use ILabs\WoocommerceDHL24\DHL24Client\WebAPI\Type\AuthData;

/**
 * GetPnp
 */
class GetPnp extends AbstractMethod implements RequestInterface {

	/**
	 * Date for which the report is generated (the report lists shipments sent on a specific date).
	 *
	 * @var \DateTime
	 */
	private $date;

	/**
	 * For which shipments it is to be generated, available dictionary values:
	 * EX - domestic express shipments up to 31.5 kg
	 * DR - domestic shipments above 31.5kg
	 * ALL - all types of shipments
	 * 2EUROPE - export shipments
	 * PR - Premium shipments
	 *
	 * @var string
	 */
	private $type;

	/**
	 * Constructor
	 *
	 * @param AuthData $authData Authorization data.
	 */
	public function __construct( AuthData $authData ) {
		parent::__construct( $authData );

		$this->date = new \DateTime();
		$this->type = 'ALL';
	}

	/**
	 * Return associative array.
	 *
	 * @return array
	 */
	public function toArray(): array {
		return array(
			'pnpRequest' => array_merge(
				parent::toArray(),
				array(
					'date' => $this->getDate()->format( 'Y-m-d' ),
					'type' => $this->getType(),
				)
			),
		);
	}

	/**
	 * Get date for which the report is generated (the report lists shipments sent on a specific date).
	 *
	 * @return \DateTime
	 */
	public function getDate(): \DateTime {
		return $this->date;
	}

	/**
	 * Set date for which the report is generated (the report lists shipments sent on a specific date).
	 *
	 * @param \DateTime $date Date for which the report is generated (the report lists shipments sent on a specific date).
	 *
	 * @return self
	 */
	public function setDate( \DateTime $date ) {
		$this->date = $date;

		return $this;
	}

	/**
	 * Get type
	 *
	 * @return string
	 */
	public function getType() {
		return $this->type;
	}

	/**
	 * Set type
	 *
	 * @param string $type Type.
	 *
	 * @return self
	 */
	public function setType( string $type ) {
		$this->type = $type;

		return $this;
	}
}
