<?php
/**
 * Class GetPostalCodeServices
 *
 * @package ILabs\WoocommerceDHL24
 */

namespace ILabs\WoocommerceDHL24\DHL24Client\WebAPI\Method;

use ILabs\WoocommerceDHL24\DHL24Client\RequestInterface;
use ILabs\WoocommerceDHL24\DHL24Client\WebAPI\Type\AuthData;

/**
 * GetPostalCodeServices
 */
class GetPostalCodeServices extends AbstractMethod implements RequestInterface {

	/**
	 * Postal code in 5-digit format (without dash).
	 *
	 * @var string
	 */
	private $postCode;

	/**
	 * Date for which the availability of services is checked.
	 *
	 * @var \DateTime
	 */
	private $pickupDate;

	/**
	 * Constructor
	 *
	 * @param AuthData $authData Authorization data.
	 */
	public function __construct( AuthData $authData ) {
		parent::__construct( $authData );

		$this->pickupDate = new \DateTime();
	}

	/**
	 * Return associative array.
	 *
	 * @return array
	 */
	public function toArray(): array {
		return array_merge(
			parent::toArray(),
			array(
				'postCode'   => $this->getPostCode(),
				'pickupDate' => $this->getPickupDate()->format( 'Y-m-d' ),
			)
		);
	}

	/**
	 * Get postal code in 5-digit format (without dash).
	 *
	 * @return  string
	 */
	public function getPostCode() {
		return $this->postCode;
	}

	/**
	 * Set postal code in 5-digit format (without dash).
	 *
	 * @param  string $postCode  Postal code in 5-digit format (without dash).
	 *
	 * @return  self
	 */
	public function setPostCode( string $postCode ) {
		$this->postCode = $postCode;

		return $this;
	}

	/**
	 * Get date for which the availability of services is checked.
	 *
	 * @return  \DateTime
	 */
	public function getPickupDate(): \DateTime {
		return $this->pickupDate;
	}

	/**
	 * Set date for which the availability of services is checked (YYYY-MM-DD).
	 *
	 * @param  \DateTime $pickupDate  Date for which the availability of services is checked (YYYY-MM-DD).
	 *
	 * @return  self
	 */
	public function setPickupDate( \DateTime $pickupDate ) {
		$this->pickupDate = $pickupDate;

		return $this;
	}
}
