<?php
/**
 * Class CustomsItem
 *
 * @package ILabs\WoocommerceDHL24
 */

namespace ILabs\WoocommerceDHL24\DHL24Client\WebAPI\Type;

/**
 * CustomsItem
 */
class CustomsItem {
	/**
	 * English name of the item.
	 *
	 * @var string|null
	 */
	private $nameEn;

	/**
	 * Polish name of the item.
	 *
	 * @var string|null
	 */
	private $namePl;

	/**
	 * Number of components.
	 *
	 * @var int|null
	 */
	private $quantity;

	/**
	 * Weight of the item.
	 *
	 * @var float|null
	 */
	private $weight;

	/**
	 * Value of the goods.
	 *
	 * @var float|null
	 */
	private $value;

	/**
	 * Customs tariff code.
	 *
	 * @var string|null
	 */
	private $tariffCode;

	/**
	 * Return associative array.
	 *
	 * @return array
	 */
	public function toArray(): array {
		return array(
			'nameEn'     => $this->getNameEn(),
			'namePl'     => $this->getNamePl(),
			'quantity'   => $this->getQuantity(),
			'weight'     => $this->getWeight(),
			'value'      => $this->getValue(),
			'tariffCode' => $this->getTariffCode(),
		);
	}

	/**
	 * Get english name of the item.
	 *
	 * @return string|null
	 */
	public function getNameEn() {
		return $this->nameEn;
	}

	/**
	 * Set english name of the item.
	 *
	 * @param string|null $nameEn English name of the item.
	 *
	 * @return self
	 */
	public function setNameEn( $nameEn ) {
		$this->nameEn = $nameEn;

		return $this;
	}

	/**
	 * Get polish name of the item.
	 *
	 * @return string|null
	 */
	public function getNamePl() {
		return $this->namePl;
	}

	/**
	 * Set polish name of the item.
	 *
	 * @param string|null $namePl Polish name of the item.
	 *
	 * @return self
	 */
	public function setNamePl( $namePl ) {
		$this->namePl = $namePl;

		return $this;
	}

	/**
	 * Get number of components.
	 *
	 * @return int|null
	 */
	public function getQuantity() {
		return $this->quantity;
	}

	/**
	 * Set number of components.
	 *
	 * @param int|null $quantity Number of components.
	 *
	 * @return self
	 */
	public function setQuantity( $quantity ) {
		$this->quantity = $quantity;

		return $this;
	}

	/**
	 * Get weight of the item.
	 *
	 * @return float|null
	 */
	public function getWeight() {
		return $this->weight;
	}

	/**
	 * Set weight of the item.
	 *
	 * @param float|null $weight Weight of the item.
	 *
	 * @return self
	 */
	public function setWeight( $weight ) {
		$this->weight = $weight;

		return $this;
	}

	/**
	 * Get value of the goods.
	 *
	 * @return float|null
	 */
	public function getValue() {
		return $this->value;
	}

	/**
	 * Set value of the goods.
	 *
	 * @param float|null $value Value of the goods.
	 *
	 * @return self
	 */
	public function setValue( $value ) {
		$this->value = $value;

		return $this;
	}

	/**
	 * Get customs tariff code.
	 *
	 * @return string|null
	 */
	public function getTariffCode() {
		return $this->tariffCode;
	}

	/**
	 * Set customs tariff code.
	 *
	 * @param string|null $tariffCode Customs tariff code.
	 *
	 * @return self
	 */
	public function setTariffCode( $tariffCode ) {
		$this->tariffCode = $tariffCode;

		return $this;
	}
}
