<?php
/**
 * Class ItemToPrint
 *
 * @package ILabs\WoocommerceDHL24
 */

namespace ILabs\WoocommerceDHL24\DHL24Client\WebAPI\Type;

use ILabs\WoocommerceDHL24\DHL24Client\ResultInterface;

/**
 * ItemToPrint
 */
class ItemToPrint {
	/**
	 * Label type.
	 * Dictionary value - one of the following values:
	 * LP - shipping label
	 * BLP - BLP label,
	 * LBLP - BLP label in A4 PDF format,
	 * ZBLP - BLP label in format used by Zebra printers
	 *
	 * @var string
	 */
	private $labelType;

	/**
	 * Shipment number.
	 * Shipment number of the shipment for which a label is to be downloaded.
	 *
	 * @var string
	 */
	private $shipmentId;

	/**
	 * Constructor
	 */
	public function __construct() {
		$this->labelType  = 'BLP';
		$this->shipmentId = '';
	}

	/**
	 * Return associative array.
	 *
	 * @return array
	 */
	public function toArray(): array {
		return array(
			'labelType'  => $this->getLabelType(),
			'shipmentId' => $this->getShipmentId(),
		);
	}

	/**
	 * Get label type.
	 *
	 * @return string
	 */
	public function getLabelType() {
		return $this->labelType;
	}

	/**
	 * Set label type.
	 *
	 * @param string $labelType Label type.
	 *
	 * @return self
	 */
	public function setLabelType( string $labelType ) {
		$this->labelType = $labelType;

		return $this;
	}

	/**
	 * Get shipment number.
	 *
	 * @return int
	 */
	public function getShipmentId(): string {
		return $this->shipmentId;
	}

	/**
	 * Set shipment number.
	 *
	 * @param string $shipmentId Shipment number.
	 *
	 * @return self
	 */
	public function setShipmentId( string $shipmentId ) {
		$this->shipmentId = $shipmentId;

		return $this;
	}
}
