<?php
/**
 * Class Label
 *
 * @package ILabs\WoocommerceDHL24
 */

namespace ILabs\WoocommerceDHL24\DHL24Client\WebAPI\Type;

/**
 * Label
 */
class Label {
	/**
	 * Label type.
	 *
	 * @var string|null
	 */
	private $labelType;

	/**
	 * MIME label format.
	 *
	 * @var string|null
	 */
	private $labelFormat;

	/**
	 * Label content (encoded in base64).
	 *
	 * @var string|null
	 */
	private $labelContent;

	/**
	 * Customs document type CN23 -returned in the case of simplified customs clearance.
	 *
	 * @var string|null
	 */
	private $cn23Content;

	/**
	 * Contents of customs document CN23 (base24) -returned in the case of simplified customs clearance.
	 *
	 * @var string|null
	 */
	private $cn23MimeType;

	/**
	 * Proforma invoice document type -returned in the case of simplified customs clearance.
	 *
	 * @var string|null
	 */
	private $fvProformaContent;

	/**
	 * Contents of proforma invoice (base64) -returned in the case of simplified customs clearance.
	 *
	 * @var string|null
	 */
	private $fvProformaMimeType;

	/**
	 * Generated invoice number - if no invoice number is provided in the input parameters.
	 *
	 * @var string|null
	 */
	private $fvProformaNumer;

	/**
	 * Get label type.
	 *
	 * @return string|null
	 */
	public function getLabelType() {
		return $this->labelType;
	}

	/**
	 * Set label type.
	 *
	 * @param string|null $labelType Label type.
	 *
	 * @return self
	 */
	public function setLabelType( $labelType ) {
		$this->labelType = $labelType;

		return $this;
	}

	/**
	 * Get mIME label format.
	 *
	 * @return string|null
	 */
	public function getLabelFormat() {
		return $this->labelFormat;
	}

	/**
	 * Set mIME label format.
	 *
	 * @param string|null $labelFormat MIME label format.
	 *
	 * @return self
	 */
	public function setLabelFormat( $labelFormat ) {
		$this->labelFormat = $labelFormat;

		return $this;
	}

	/**
	 * Get label content (encoded in base64).
	 *
	 * @return string|null
	 */
	public function getLabelContent() {
		return $this->labelContent;
	}

	/**
	 * Set label content (encoded in base64).
	 *
	 * @param string|null $labelContent Label content (encoded in base64).
	 *
	 * @return self
	 */
	public function setLabelContent( $labelContent ) {
		$this->labelContent = $labelContent;

		return $this;
	}

	/**
	 * Get customs document type CN23 -returned in the case of simplified customs clearance.
	 *
	 * @return string|null
	 */
	public function getCn23Content() {
		return $this->cn23Content;
	}

	/**
	 * Set customs document type CN23 -returned in the case of simplified customs clearance.
	 *
	 * @param string|null $cn23Content Customs document type CN23 -returned in the case of simplified customs clearance.
	 *
	 * @return self
	 */
	public function setCn23Content( $cn23Content ) {
		$this->cn23Content = $cn23Content;

		return $this;
	}

	/**
	 * Get contents of customs document CN23 (base24) -returned in the case of simplified customs clearance.
	 *
	 * @return string|null
	 */
	public function getCn23MimeType() {
		return $this->cn23MimeType;
	}

	/**
	 * Set contents of customs document CN23 (base24) -returned in the case of simplified customs clearance.
	 *
	 * @param string|null $cn23MimeType Contents of customs document CN23 (base24) -returned in the case of simplified customs clearance.
	 *
	 * @return self
	 */
	public function setCn23MimeType( $cn23MimeType ) {
		$this->cn23MimeType = $cn23MimeType;

		return $this;
	}

	/**
	 * Get proforma invoice document type -returned in the case of simplified customs clearance.
	 *
	 * @return string|null
	 */
	public function getFvProformaContent() {
		return $this->fvProformaContent;
	}

	/**
	 * Set proforma invoice document type -returned in the case of simplified customs clearance.
	 *
	 * @param string|null $fvProformaContent Proforma invoice document type -returned in the case of simplified customs clearance.
	 *
	 * @return self
	 */
	public function setFvProformaContent( $fvProformaContent ) {
		$this->fvProformaContent = $fvProformaContent;

		return $this;
	}

	/**
	 * Get contents of proforma invoice (base64) -returned in the case of simplified customs clearance.
	 *
	 * @return string|null
	 */
	public function getFvProformaMimeType() {
		return $this->fvProformaMimeType;
	}

	/**
	 * Set contents of proforma invoice (base64) -returned in the case of simplified customs clearance.
	 *
	 * @param string|null $fvProformaMimeType Contents of proforma invoice (base64) -returned in the case of simplified customs clearance.
	 *
	 * @return self
	 */
	public function setFvProformaMimeType( $fvProformaMimeType ) {
		$this->fvProformaMimeType = $fvProformaMimeType;

		return $this;
	}

	/**
	 * Get generated invoice number - if no invoice number is provided in the input parameters.
	 *
	 * @return string|null
	 */
	public function getFvProformaNumer() {
		return $this->fvProformaNumer;
	}

	/**
	 * Set generated invoice number - if no invoice number is provided in the input parameters.
	 *
	 * @param string|null $fvProformaNumer Generated invoice number - if no invoice number is provided in the input parameters.
	 *
	 * @return self
	 */
	public function setFvProformaNumer( $fvProformaNumer ) {
		$this->fvProformaNumer = $fvProformaNumer;

		return $this;
	}
}
