<?php
/**
 * Class PieceDefinitionLabel
 *
 * @package ILabs\WoocommerceDHL24
 */

namespace ILabs\WoocommerceDHL24\DHL24Client\WebAPI\Type;

/**
 * PieceDefinitionLabel
 */
class PieceDefinitionLabel {
	/**
	 * Routing code.
	 *
	 * @var string|null
	 */
	private $routingBarcode;

	/**
	 * Parcel type.
	 *
	 * @var string|null
	 */
	private $type;

	/**
	 * Width of the parcel (in centimetres), not applicable to type = ENVELOPE.
	 *
	 * @var int|null
	 */
	private $width;

	/**
	 * Height of the parcel (in centimetres), not applicable to type = ENVELOPE.
	 *
	 * @var int|null
	 */
	private $height;

	/**
	 * Length of the parcel (in centimetres), not applicable to type = ENVELOPE.
	 *
	 * @var int|null
	 */
	private $length;

	/**
	 * Weight of the parcel (in kilograms), not applicable to type = ENVELOPE.
	 *
	 * @var float|null
	 */
	private $weight;

	/**
	 * Quantity of parcels of this type.
	 *
	 * @var int|null
	 */
	private $quantity;

	/**
	 * Indication that the parcel is non-standard (true / false).
	 *
	 * @var bool|null
	 */
	private $nonStandard;

	/**
	 * Parcel ID (JJD) for BLP label (for customers with their own numbering).
	 *
	 * @var string|null
	 */
	private $blpPieceId;

	/**
	 * Indication that the pallets in the shipment are to bereturned (true / false).
	 *
	 * @var bool|null
	 */
	private $euroReturn;

	/**
	 * Get routing code.
	 *
	 * @return string|null
	 */
	public function getRoutingBarcode() {
		return $this->routingBarcode;
	}

	/**
	 * Set routing code.
	 *
	 * @param string|null $routingBarcode Routing code.
	 *
	 * @return self
	 */
	public function setRoutingBarcode( $routingBarcode ) {
		$this->routingBarcode = $routingBarcode;

		return $this;
	}

	/**
	 * Get parcel type.
	 *
	 * @return string|null
	 */
	public function getType() {
		return $this->type;
	}

	/**
	 * Set parcel type.
	 *
	 * @param string|null $type Parcel type.
	 *
	 * @return self
	 */
	public function setType( $type ) {
		$this->type = $type;

		return $this;
	}

	/**
	 * Get width of the parcel (in centimetres), not applicable to type = ENVELOPE.
	 *
	 * @return int|null
	 */
	public function getWidth() {
		return $this->width;
	}

	/**
	 * Set width of the parcel (in centimetres), not applicable to type = ENVELOPE.
	 *
	 * @param int|null $width Width of the parcel (in centimetres), not applicable to type = ENVELOPE.
	 *
	 * @return self
	 */
	public function setWidth( $width ) {
		$this->width = $width;

		return $this;
	}

	/**
	 * Get height of the parcel (in centimetres), not applicable to type = ENVELOPE.
	 *
	 * @return int|null
	 */
	public function getHeight() {
		return $this->height;
	}

	/**
	 * Set height of the parcel (in centimetres), not applicable to type = ENVELOPE.
	 *
	 * @param int|null $height Height of the parcel (in centimetres), not applicable to type = ENVELOPE.
	 *
	 * @return self
	 */
	public function setHeight( $height ) {
		$this->height = $height;

		return $this;
	}

	/**
	 * Get length of the parcel (in centimetres), not applicable to type = ENVELOPE.
	 *
	 * @return int|null
	 */
	public function getLength() {
		return $this->length;
	}

	/**
	 * Set length of the parcel (in centimetres), not applicable to type = ENVELOPE.
	 *
	 * @param int|null $length Length of the parcel (in centimetres), not applicable to type = ENVELOPE.
	 *
	 * @return self
	 */
	public function setLength( $length ) {
		$this->length = $length;

		return $this;
	}

	/**
	 * Get weight of the parcel (in kilograms), not applicable to type = ENVELOPE.
	 *
	 * @return float|null
	 */
	public function getWeight() {
		return $this->weight;
	}

	/**
	 * Set weight of the parcel (in kilograms), not applicable to type = ENVELOPE.
	 *
	 * @param float|null $weight Weight of the parcel (in kilograms), not applicable to type = ENVELOPE.
	 *
	 * @return self
	 */
	public function setWeight( $weight ) {
		$this->weight = $weight;

		return $this;
	}

	/**
	 * Get quantity of parcels of this type.
	 *
	 * @return int|null
	 */
	public function getQuantity() {
		return $this->quantity;
	}

	/**
	 * Set quantity of parcels of this type.
	 *
	 * @param int|null $quantity Quantity of parcels of this type.
	 *
	 * @return self
	 */
	public function setQuantity( $quantity ) {
		$this->quantity = $quantity;

		return $this;
	}

	/**
	 * Get indication that the parcel is non-standard (true / false).
	 *
	 * @return bool|null
	 */
	public function getNonStandard() {
		return $this->nonStandard;
	}

	/**
	 * Set indication that the parcel is non-standard (true / false).
	 *
	 * @param bool|null $nonStandard Indication that the parcel is non-standard (true / false).
	 *
	 * @return self
	 */
	public function setNonStandard( $nonStandard ) {
		$this->nonStandard = $nonStandard;

		return $this;
	}

	/**
	 * Get parcel ID (JJD) for BLP label (for customers with their own numbering).
	 *
	 * @return string|null
	 */
	public function getBlpPieceId() {
		return $this->blpPieceId;
	}

	/**
	 * Set parcel ID (JJD) for BLP label (for customers with their own numbering).
	 *
	 * @param string|null $blpPieceId Parcel ID (JJD) for BLP label (for customers with their own numbering).
	 *
	 * @return self
	 */
	public function setBlpPieceId( $blpPieceId ) {
		$this->blpPieceId = $blpPieceId;

		return $this;
	}

	/**
	 * Get indication that the pallets in the shipment are to bereturned (true / false).
	 *
	 * @return bool|null
	 */
	public function getEuroReturn() {
		return $this->euroReturn;
	}

	/**
	 * Set indication that the pallets in the shipment are to bereturned (true / false).
	 *
	 * @param bool|null $euroReturn Indication that the pallets in the shipment are to bereturned (true / false).
	 *
	 * @return self
	 */
	public function setEuroReturn( $euroReturn ) {
		$this->euroReturn = $euroReturn;

		return $this;
	}
}
