<?php
/**
 * Class ReceiverAddressLabel
 *
 * @package ILabs\WoocommerceDHL24
 */

namespace ILabs\WoocommerceDHL24\DHL24Client\WebAPI\Type;

/**
 * ReceiverAddressLabel
 */
class ReceiverAddressLabel {
	/**
	 * Name and surname of the contact person.
	 *
	 * @var string|null
	 */
	private $contactPerson;

	/**
	 * Contact phone number.
	 *
	 * @var string|null
	 */
	private $contactPhone;

	/**
	 * Contact e-mail.
	 *
	 * @var string|null
	 */
	private $contactEmail;

	/**
	 * Name and surname for pre-delivery notification.
	 *
	 * @var string|null
	 */
	private $preavisoPhone;

	/**
	 * Phone number for pre-delivery notification.
	 *
	 * @var string|null
	 */
	private $preavisoEmail;

	/**
	 * E-mail address for pre-delivery notification.
	 *
	 * @var string|null
	 */
	private $preavisoPerson;

	/**
	 * Recipient’s country.
	 *
	 * @var string|null
	 */
	private $country;

	/**
	 * Delivery to DHL Parcelstation.
	 *
	 * @var bool|null
	 */
	private $isPackstation;

	/**
	 * Delivery to DHL Parcelshop.
	 *
	 * @var bool|null
	 */
	private $isPostfiliale;

	/**
	 * Customer number - only for DE with deliveries to parcel locker.
	 *
	 * @var string|null
	 */
	private $postnummer;

	/**
	 * Address type.
	 *
	 * @var string|null
	 */
	private $addressType;

	/**
	 * Name (first name and surname or company name).
	 *
	 * @var string|null
	 */
	private $name;

	/**
	 * Postal code.
	 *
	 * @var string|null
	 */
	private $postalCode;

	/**
	 * Town/city.
	 *
	 * @var string|null
	 */
	private $city;

	/**
	 * Street.
	 *
	 * @var string|null
	 */
	private $street;

	/**
	 * House number.
	 * In the case of deliveries of international Connect shipments to DHL Parcelstation or DHL Parcelshop - parcelstation or parcelshop number.
	 *
	 * @var string|null
	 */
	private $houseNumber;

	/**
	 * Apartment number.
	 *
	 * @var string|null
	 */
	private $apartmentNumber;

	/**
	 * Get name and surname of the contact person.
	 *
	 * @return string|null
	 */
	public function getContactPerson() {
		return $this->contactPerson;
	}

	/**
	 * Set name and surname of the contact person.
	 *
	 * @param string|null $contactPerson Name and surname of the contact person.
	 *
	 * @return self
	 */
	public function setContactPerson( $contactPerson ) {
		$this->contactPerson = $contactPerson;

		return $this;
	}

	/**
	 * Get contact phone number.
	 *
	 * @return string|null
	 */
	public function getContactPhone() {
		return $this->contactPhone;
	}

	/**
	 * Set contact phone number.
	 *
	 * @param string|null $contactPhone Contact phone number.
	 *
	 * @return self
	 */
	public function setContactPhone( $contactPhone ) {
		$this->contactPhone = $contactPhone;

		return $this;
	}

	/**
	 * Get contact e-mail.
	 *
	 * @return string|null
	 */
	public function getContactEmail() {
		return $this->contactEmail;
	}

	/**
	 * Set contact e-mail.
	 *
	 * @param string|null $contactEmail Contact e-mail.
	 *
	 * @return self
	 */
	public function setContactEmail( $contactEmail ) {
		$this->contactEmail = $contactEmail;

		return $this;
	}

	/**
	 * Get name and surname for pre-delivery notification.
	 *
	 * @return string|null
	 */
	public function getPreavisoPhone() {
		return $this->preavisoPhone;
	}

	/**
	 * Set name and surname for pre-delivery notification.
	 *
	 * @param string|null $preavisoPhone Name and surname for pre-delivery notification.
	 *
	 * @return self
	 */
	public function setPreavisoPhone( $preavisoPhone ) {
		$this->preavisoPhone = $preavisoPhone;

		return $this;
	}

	/**
	 * Get phone number for pre-delivery notification.
	 *
	 * @return string|null
	 */
	public function getPreavisoEmail() {
		return $this->preavisoEmail;
	}

	/**
	 * Set phone number for pre-delivery notification.
	 *
	 * @param string|null $preavisoEmail Phone number for pre-delivery notification.
	 *
	 * @return self
	 */
	public function setPreavisoEmail( $preavisoEmail ) {
		$this->preavisoEmail = $preavisoEmail;

		return $this;
	}

	/**
	 * Get e-mail address for pre-delivery notification.
	 *
	 * @return string|null
	 */
	public function getPreavisoPerson() {
		return $this->preavisoPerson;
	}

	/**
	 * Set e-mail address for pre-delivery notification.
	 *
	 * @param string|null $preavisoPerson E-mail address for pre-delivery notification.
	 *
	 * @return self
	 */
	public function setPreavisoPerson( $preavisoPerson ) {
		$this->preavisoPerson = $preavisoPerson;

		return $this;
	}

	/**
	 * Get recipient’s country.
	 *
	 * @return string|null
	 */
	public function getCountry() {
		return $this->country;
	}

	/**
	 * Set recipient’s country.
	 *
	 * @param string|null $country Recipient’s country.
	 *
	 * @return self
	 */
	public function setCountry( $country ) {
		$this->country = $country;

		return $this;
	}

	/**
	 * Get delivery to DHL Parcelstation.
	 *
	 * @return bool|null
	 */
	public function getIsPackstation() {
		return $this->isPackstation;
	}

	/**
	 * Set delivery to DHL Parcelstation.
	 *
	 * @param bool|null $isPackstation Delivery to DHL Parcelstation.
	 *
	 * @return self
	 */
	public function setIsPackstation( $isPackstation ) {
		$this->isPackstation = $isPackstation;

		return $this;
	}

	/**
	 * Get delivery to DHL Parcelshop.
	 *
	 * @return bool|null
	 */
	public function getIsPostfiliale() {
		return $this->isPostfiliale;
	}

	/**
	 * Set delivery to DHL Parcelshop.
	 *
	 * @param bool|null $isPostfiliale Delivery to DHL Parcelshop.
	 *
	 * @return self
	 */
	public function setIsPostfiliale( $isPostfiliale ) {
		$this->isPostfiliale = $isPostfiliale;

		return $this;
	}

	/**
	 * Get customer number - only for DE with deliveries to parcel locker.
	 *
	 * @return string|null
	 */
	public function getPostnummer() {
		return $this->postnummer;
	}

	/**
	 * Set customer number - only for DE with deliveries to parcel locker.
	 *
	 * @param string|null $postnummer Customer number - only for DE with deliveries to parcel locker.
	 *
	 * @return self
	 */
	public function setPostnummer( $postnummer ) {
		$this->postnummer = $postnummer;

		return $this;
	}

	/**
	 * Get address type.
	 *
	 * @return string|null
	 */
	public function getAddressType() {
		return $this->addressType;
	}

	/**
	 * Set address type.
	 *
	 * @param string|null $addressType Address type.
	 *
	 * @return self
	 */
	public function setAddressType( $addressType ) {
		$this->addressType = $addressType;

		return $this;
	}

	/**
	 * Get name (first name and surname or company name).
	 *
	 * @return string|null
	 */
	public function getName() {
		return $this->name;
	}

	/**
	 * Set name (first name and surname or company name).
	 *
	 * @param string|null $name Name (first name and surname or company name).
	 *
	 * @return self
	 */
	public function setName( $name ) {
		$this->name = $name;

		return $this;
	}

	/**
	 * Get postal code.
	 *
	 * @return string|null
	 */
	public function getPostalCode() {
		return $this->postalCode;
	}

	/**
	 * Set postal code.
	 *
	 * @param string|null $postalCode Postal code.
	 *
	 * @return self
	 */
	public function setPostalCode( $postalCode ) {
		$this->postalCode = $postalCode;

		return $this;
	}

	/**
	 * Get town/city.
	 *
	 * @return string|null
	 */
	public function getCity() {
		return $this->city;
	}

	/**
	 * Set town/city.
	 *
	 * @param string|null $city Town/city.
	 *
	 * @return self
	 */
	public function setCity( $city ) {
		$this->city = $city;

		return $this;
	}

	/**
	 * Get street.
	 *
	 * @return string|null
	 */
	public function getStreet() {
		return $this->street;
	}

	/**
	 * Set street.
	 *
	 * @param string|null $street Street.
	 *
	 * @return self
	 */
	public function setStreet( $street ) {
		$this->street = $street;

		return $this;
	}

	/**
	 * Get house number.
	 *
	 * @return string|null
	 */
	public function getHouseNumber() {
		return $this->houseNumber;
	}

	/**
	 * Set house number.
	 *
	 * @param string|null $houseNumber In the case of deliveries of international Connect shipments to DHL Parcelstation or DHL Parcelshop - parcelstation or parcelshop number.
	 *
	 * @return self
	 */
	public function setHouseNumber( $houseNumber ) {
		$this->houseNumber = $houseNumber;

		return $this;
	}

	/**
	 * Get apartment number.
	 *
	 * @return string|null
	 */
	public function getApartmentNumber() {
		return $this->apartmentNumber;
	}

	/**
	 * Set apartment number.
	 *
	 * @param string|null $apartmentNumber Apartment number.
	 *
	 * @return self
	 */
	public function setApartmentNumber( $apartmentNumber ) {
		$this->apartmentNumber = $apartmentNumber;

		return $this;
	}
}
