<?php
/**
 * Class ReturnPackage
 *
 * @package ILabs\WoocommerceDHL24
 */

namespace ILabs\WoocommerceDHL24\DHL24Client\WebAPI\Type;

/**
 * ReturnPackage
 */
class ReturnPackage {
	/**
	 * One of the values: "ENVELOPE", "PACKAGE", "PALLET".
	 *
	 * @var string|null
	 */
	private $type;

	/**
	 * Width in centimetres, required if the type is other than "ENVELOPE".
	 *
	 * @var int|null
	 */
	private $width;

	/**
	 * Height in centimetres, required if the type is other than "ENVELOPE".
	 *
	 * @var int|null
	 */
	private $height;

	/**
	 * Length in centimetres, required if the type is other than "ENVELOPE".
	 *
	 * @var int|null
	 */
	private $length;

	/**
	 * Weight in kilograms, required if the type is other than "ENVELOPE".
	 *
	 * @var float|null
	 */
	private $weight;

	/**
	 * Quantity of parcels.
	 *
	 * @var int|null
	 */
	private $quantity;

	/**
	 * Is the parcel non-standard (according to the price list definition).
	 *
	 * @var bool|null
	 */
	private $nonStandard;

	/**
	 * BLP identifier - for customers printing labels of this type, with their own parcel numbering.
	 *
	 * @var string|null
	 */
	private $blpPieceId;

	/**
	 * Return associative array.
	 *
	 * @return array
	 */
	public function toArray(): array {
		return array(
			'type'        => $this->getType(),
			'width'       => $this->getWidth(),
			'height'      => $this->getHeight(),
			'length'      => $this->getLength(),
			'weight'      => $this->getWeight(),
			'quantity'    => $this->getQuantity(),
			'nonStandard' => $this->getNonStandard(),
			'blpPieceId'  => $this->getBlpPieceId(),
		);
	}

	/**
	 * Get one of the values: "ENVELOPE", "PACKAGE", "PALLET".
	 *
	 * @return string|null
	 */
	public function getType() {
		return $this->type;
	}

	/**
	 * Set one of the values: "ENVELOPE", "PACKAGE", "PALLET".
	 *
	 * @param string|null $type One of the values: "ENVELOPE", "PACKAGE", "PALLET".
	 *
	 * @return self
	 */
	public function setType( $type ) {
		$this->type = $type;

		return $this;
	}

	/**
	 * Get width in centimetres, required if the type is other than "ENVELOPE".
	 *
	 * @return int|null
	 */
	public function getWidth() {
		return $this->width;
	}

	/**
	 * Set width in centimetres, required if the type is other than "ENVELOPE".
	 *
	 * @param int|null $width Width in centimetres, required if the type is other than "ENVELOPE".
	 *
	 * @return self
	 */
	public function setWidth( $width ) {
		$this->width = $width;

		return $this;
	}

	/**
	 * Get height in centimetres, required if the type is other than "ENVELOPE".
	 *
	 * @return int|null
	 */
	public function getHeight() {
		return $this->height;
	}

	/**
	 * Set height in centimetres, required if the type is other than "ENVELOPE".
	 *
	 * @param int|null $height Height in centimetres, required if the type is other than "ENVELOPE".
	 *
	 * @return self
	 */
	public function setHeight( $height ) {
		$this->height = $height;

		return $this;
	}

	/**
	 * Get length in centimetres, required if the type is other than "ENVELOPE".
	 *
	 * @return int|null
	 */
	public function getLength() {
		return $this->length;
	}

	/**
	 * Set length in centimetres, required if the type is other than "ENVELOPE".
	 *
	 * @param int|null $length Length in centimetres, required if the type is other than "ENVELOPE".
	 *
	 * @return self
	 */
	public function setLength( $length ) {
		$this->length = $length;

		return $this;
	}

	/**
	 * Get weight in kilograms, required if the type is other than "ENVELOPE".
	 *
	 * @return float|null
	 */
	public function getWeight() {
		return $this->weight;
	}

	/**
	 * Set weight in kilograms, required if the type is other than "ENVELOPE".
	 *
	 * @param float|null $weight Weight in kilograms, required if the type is other than "ENVELOPE".
	 *
	 * @return self
	 */
	public function setWeight( $weight ) {
		$this->weight = $weight;

		return $this;
	}

	/**
	 * Get quantity of parcels.
	 *
	 * @return int|null
	 */
	public function getQuantity() {
		return $this->quantity;
	}

	/**
	 * Set quantity of parcels.
	 *
	 * @param int|null $quantity Quantity of parcels.
	 *
	 * @return self
	 */
	public function setQuantity( $quantity ) {
		$this->quantity = $quantity;

		return $this;
	}

	/**
	 * Get is the parcel non-standard (according to the price list definition).
	 *
	 * @return bool|null
	 */
	public function getNonStandard() {
		return $this->nonStandard;
	}

	/**
	 * Set is the parcel non-standard (according to the price list definition).
	 *
	 * @param bool|null $nonStandard Is the parcel non-standard (according to the price list definition).
	 *
	 * @return self
	 */
	public function setNonStandard( $nonStandard ) {
		$this->nonStandard = $nonStandard;

		return $this;
	}

	/**
	 * Get bLP identifier - for customers printing labels of this type, with their own parcel numbering.
	 *
	 * @return string|null
	 */
	public function getBlpPieceId() {
		return $this->blpPieceId;
	}

	/**
	 * Set bLP identifier - for customers printing labels of this type, with their own parcel numbering.
	 *
	 * @param string|null $blpPieceId BLP identifier - for customers printing labels of this type, with their own parcel numbering.
	 *
	 * @return self
	 */
	public function setBlpPieceId( $blpPieceId ) {
		$this->blpPieceId = $blpPieceId;

		return $this;
	}
}
