<?php
/**
 * Class ReturnParam
 *
 * @package ILabs\WoocommerceDHL24
 */

namespace ILabs\WoocommerceDHL24\DHL24Client\WebAPI\Type;

/**
 * ReturnParam
 */
class ReturnParam {
	/**
	 * Two-letter country code.
	 *
	 * @var string|null
	 */
	private $countryCode;

	/**
	 * Product code.
	 *
	 * @var string|null
	 */
	private $product;

	/**
	 * Header on the label.
	 *
	 * @var string|null
	 */
	private $pieceHeader;

	/**
	 * Routing code.
	 *
	 * @var string|null
	 */
	private $routing;

	/**
	 * 2L code.
	 *
	 * @var string|null
	 */
	private $code2l;

	/**
	 * Courier availability.
	 *
	 * @var bool|null
	 */
	private $courierAvailable;

	/**
	 * Maximum weight for courier delivery.
	 *
	 * @var float|null
	 */
	private $courierMaxWeight;

	/**
	 * Maximum width for courier delivery.
	 *
	 * @var int|null
	 */
	private $courierMaxWidth;

	/**
	 * Maximum height for courier delivery.
	 *
	 * @var int|null
	 */
	private $courierMaxHeight;

	/**
	 * Maximum length for courier delivery.
	 *
	 * @var int|null
	 */
	private $courierMaxLength;

	/**
	 * Maximum COD amount.
	 *
	 * @var int|null
	 */
	private $courierMaxCod;

	/**
	 * Availability of NST.
	 *
	 * @var bool|null
	 */
	private $courierNstAvailable;

	/**
	 * Maximum dimensions for NST.
	 *
	 * @var int|null
	 */
	private $maxNst;

	/**
	 * Maximum GIRTH (circumference of the parcel 1 x length + 2 x (width + height).
	 *
	 * @var int|null
	 */
	private $maxGirth;

	/**
	 * Availability of delivery to parcel lockers.
	 *
	 * @var bool|null
	 */
	private $packstationAvailable;

	/**
	 * Maximum weight for parcel locker delivery.
	 *
	 * @var float|null
	 */
	private $packstationMaxWeight;

	/**
	 * Maximum width for parcel locker delivery.
	 *
	 * @var int|null
	 */
	private $packstationMaxWidth;

	/**
	 * Maximum width for parcel locker delivery.
	 *
	 * @var int|null
	 */
	private $packstationMaxHeight;

	/**
	 * Availability of delivery to NST parcel locker.
	 *
	 * @var bool|null
	 */
	private $packstationNstAvailable;

	/**
	 * Maximum length for parcel locker delivery.
	 *
	 * @var int|null
	 */
	private $packstationMaxLength;

	/**
	 * Availability of delivery to Parcelshop points.
	 *
	 * @var bool|null
	 */
	private $postfilialeAvailable;

	/**
	 * Maximum weight for Parcelshop delivery.
	 *
	 * @var float|null
	 */
	private $postfilialeMaxWeight;

	/**
	 * Maximum width for Parcelshop delivery.
	 *
	 * @var int|null
	 */
	private $postfilialeMaxWidth;

	/**
	 * Maximum height for Parcelshop delivery.
	 *
	 * @var int|null
	 */
	private $postfilialeMaxHeight;

	/**
	 * Availability of NST delivery to Parcelshop points.
	 *
	 * @var bool|null
	 */
	private $postfilialeNstAvailable;

	/**
	 * Maximum length for Parcelshop delivery.
	 *
	 * @var int|null
	 */
	private $postfilialeMaxLength;

	/**
	 * Postal code format.
	 *
	 * @var string|null
	 */
	private $zipFormat;


	/**
	 * Get two-letter country code.
	 *
	 * @return string|null
	 */
	public function getCountryCode() {
		return $this->countryCode;
	}

	/**
	 * Set two-letter country code.
	 *
	 * @param string|null $countryCode Two-letter country code.
	 *
	 * @return self
	 */
	public function setCountryCode( $countryCode ) {
		$this->countryCode = $countryCode;

		return $this;
	}

	/**
	 * Get product code.
	 *
	 * @return string|null
	 */
	public function getProduct() {
		return $this->product;
	}

	/**
	 * Set product code.
	 *
	 * @param string|null $product Product code.
	 *
	 * @return self
	 */
	public function setProduct( $product ) {
		$this->product = $product;

		return $this;
	}

	/**
	 * Get header on the label.
	 *
	 * @return string|null
	 */
	public function getPieceHeader() {
		return $this->pieceHeader;
	}

	/**
	 * Set header on the label.
	 *
	 * @param string|null $pieceHeader Header on the label.
	 *
	 * @return self
	 */
	public function setPieceHeader( $pieceHeader ) {
		$this->pieceHeader = $pieceHeader;

		return $this;
	}

	/**
	 * Get routing code.
	 *
	 * @return string|null
	 */
	public function getRouting() {
		return $this->routing;
	}

	/**
	 * Set routing code.
	 *
	 * @param string|null $routing Routing code.
	 *
	 * @return self
	 */
	public function setRouting( $routing ) {
		$this->routing = $routing;

		return $this;
	}

	/**
	 * Get 2L code.
	 *
	 * @return string|null
	 */
	public function getCode2l() {
		return $this->code2l;
	}

	/**
	 * Set 2L code.
	 *
	 * @param string|null $code2l 2L code.
	 *
	 * @return self
	 */
	public function setCode2l( $code2l ) {
		$this->code2l = $code2l;

		return $this;
	}

	/**
	 * Get courier availability.
	 *
	 * @return bool|null
	 */
	public function getCourierAvailable() {
		return $this->courierAvailable;
	}

	/**
	 * Set courier availability.
	 *
	 * @param bool|null $courierAvailable Courier availability.
	 *
	 * @return self
	 */
	public function setCourierAvailable( $courierAvailable ) {
		$this->courierAvailable = $courierAvailable;

		return $this;
	}

	/**
	 * Get maximum weight for courier delivery.
	 *
	 * @return float|null
	 */
	public function getCourierMaxWeight() {
		return $this->courierMaxWeight;
	}

	/**
	 * Set maximum weight for courier delivery.
	 *
	 * @param float|null $courierMaxWeight Maximum weight for courier delivery.
	 *
	 * @return self
	 */
	public function setCourierMaxWeight( $courierMaxWeight ) {
		$this->courierMaxWeight = $courierMaxWeight;

		return $this;
	}

	/**
	 * Get maximum width for courier delivery.
	 *
	 * @return int|null
	 */
	public function getCourierMaxWidth() {
		return $this->courierMaxWidth;
	}

	/**
	 * Set maximum width for courier delivery.
	 *
	 * @param int|null $courierMaxWidth Maximum width for courier delivery.
	 *
	 * @return self
	 */
	public function setCourierMaxWidth( $courierMaxWidth ) {
		$this->courierMaxWidth = $courierMaxWidth;

		return $this;
	}

	/**
	 * Get maximum height for courier delivery.
	 *
	 * @return int|null
	 */
	public function getCourierMaxHeight() {
		return $this->courierMaxHeight;
	}

	/**
	 * Set maximum height for courier delivery.
	 *
	 * @param int|null $courierMaxHeight Maximum height for courier delivery.
	 *
	 * @return self
	 */
	public function setCourierMaxHeight( $courierMaxHeight ) {
		$this->courierMaxHeight = $courierMaxHeight;

		return $this;
	}

	/**
	 * Get maximum length for courier delivery.
	 *
	 * @return int|null
	 */
	public function getCourierMaxLength() {
		return $this->courierMaxLength;
	}

	/**
	 * Set maximum length for courier delivery.
	 *
	 * @param int|null $courierMaxLength Maximum length for courier delivery.
	 *
	 * @return self
	 */
	public function setCourierMaxLength( $courierMaxLength ) {
		$this->courierMaxLength = $courierMaxLength;

		return $this;
	}

	/**
	 * Get maximum COD amount.
	 *
	 * @return int|null
	 */
	public function getCourierMaxCod() {
		return $this->courierMaxCod;
	}

	/**
	 * Set maximum COD amount.
	 *
	 * @param int|null $courierMaxCod Maximum COD amount.
	 *
	 * @return self
	 */
	public function setCourierMaxCod( $courierMaxCod ) {
		$this->courierMaxCod = $courierMaxCod;

		return $this;
	}

	/**
	 * Get availability of NST.
	 *
	 * @return bool|null
	 */
	public function getCourierNstAvailable() {
		return $this->courierNstAvailable;
	}

	/**
	 * Set availability of NST.
	 *
	 * @param bool|null $courierNstAvailable Availability of NST.
	 *
	 * @return self
	 */
	public function setCourierNstAvailable( $courierNstAvailable ) {
		$this->courierNstAvailable = $courierNstAvailable;

		return $this;
	}

	/**
	 * Get maximum dimensions for NST.
	 *
	 * @return int|null
	 */
	public function getMaxNst() {
		return $this->maxNst;
	}

	/**
	 * Set maximum dimensions for NST.
	 *
	 * @param int|null $maxNst Maximum dimensions for NST.
	 *
	 * @return self
	 */
	public function setMaxNst( $maxNst ) {
		$this->maxNst = $maxNst;

		return $this;
	}

	/**
	 * Get maximum GIRTH (circumference of the parcel 1 x length + 2 x (width + height).
	 *
	 * @return int|null
	 */
	public function getMaxGirth() {
		return $this->maxGirth;
	}

	/**
	 * Set maximum GIRTH (circumference of the parcel 1 x length + 2 x (width + height).
	 *
	 * @param int|null $maxGirth Maximum GIRTH (circumference of the parcel 1 x length + 2 x (width + height).
	 *
	 * @return self
	 */
	public function setMaxGirth( $maxGirth ) {
		$this->maxGirth = $maxGirth;

		return $this;
	}

	/**
	 * Get availability of delivery to parcel lockers.
	 *
	 * @return bool|null
	 */
	public function getPackstationAvailable() {
		return $this->packstationAvailable;
	}

	/**
	 * Set availability of delivery to parcel lockers.
	 *
	 * @param bool|null $packstationAvailable Availability of delivery to parcel lockers.
	 *
	 * @return self
	 */
	public function setPackstationAvailable( $packstationAvailable ) {
		$this->packstationAvailable = $packstationAvailable;

		return $this;
	}

	/**
	 * Get maximum weight for parcel locker delivery.
	 *
	 * @return float|null
	 */
	public function getPackstationMaxWeight() {
		return $this->packstationMaxWeight;
	}

	/**
	 * Set maximum weight for parcel locker delivery.
	 *
	 * @param float|null $packstationMaxWeight Maximum weight for parcel locker delivery.
	 *
	 * @return self
	 */
	public function setPackstationMaxWeight( $packstationMaxWeight ) {
		$this->packstationMaxWeight = $packstationMaxWeight;

		return $this;
	}

	/**
	 * Get maximum width for parcel locker delivery.
	 *
	 * @return int|null
	 */
	public function getPackstationMaxWidth() {
		return $this->packstationMaxWidth;
	}

	/**
	 * Set maximum width for parcel locker delivery.
	 *
	 * @param int|null $packstationMaxWidth Maximum width for parcel locker delivery.
	 *
	 * @return self
	 */
	public function setPackstationMaxWidth( $packstationMaxWidth ) {
		$this->packstationMaxWidth = $packstationMaxWidth;

		return $this;
	}

	/**
	 * Get maximum width for parcel locker delivery.
	 *
	 * @return int|null
	 */
	public function getPackstationMaxHeight() {
		return $this->packstationMaxHeight;
	}

	/**
	 * Set maximum width for parcel locker delivery.
	 *
	 * @param int|null $packstationMaxHeight Maximum width for parcel locker delivery.
	 *
	 * @return self
	 */
	public function setPackstationMaxHeight( $packstationMaxHeight ) {
		$this->packstationMaxHeight = $packstationMaxHeight;

		return $this;
	}

	/**
	 * Get availability of delivery to NST parcel locker.
	 *
	 * @return bool|null
	 */
	public function getPackstationNstAvailable() {
		return $this->packstationNstAvailable;
	}

	/**
	 * Set availability of delivery to NST parcel locker.
	 *
	 * @param bool|null $packstationNstAvailable Availability of delivery to NST parcel locker.
	 *
	 * @return self
	 */
	public function setPackstationNstAvailable( $packstationNstAvailable ) {
		$this->packstationNstAvailable = $packstationNstAvailable;

		return $this;
	}

	/**
	 * Get maximum length for parcel locker delivery.
	 *
	 * @return int|null
	 */
	public function getPackstationMaxLength() {
		return $this->packstationMaxLength;
	}

	/**
	 * Set maximum length for parcel locker delivery.
	 *
	 * @param int|null $packstationMaxLength Maximum length for parcel locker delivery.
	 *
	 * @return self
	 */
	public function setPackstationMaxLength( $packstationMaxLength ) {
		$this->packstationMaxLength = $packstationMaxLength;

		return $this;
	}

	/**
	 * Get availability of delivery to Parcelshop points.
	 *
	 * @return bool|null
	 */
	public function getPostfilialeAvailable() {
		return $this->postfilialeAvailable;
	}

	/**
	 * Set availability of delivery to Parcelshop points.
	 *
	 * @param bool|null $postfilialeAvailable Availability of delivery to Parcelshop points.
	 *
	 * @return self
	 */
	public function setPostfilialeAvailable( $postfilialeAvailable ) {
		$this->postfilialeAvailable = $postfilialeAvailable;

		return $this;
	}

	/**
	 * Get maximum weight for Parcelshop delivery.
	 *
	 * @return float|null
	 */
	public function getPostfilialeMaxWeight() {
		return $this->postfilialeMaxWeight;
	}

	/**
	 * Set maximum weight for Parcelshop delivery.
	 *
	 * @param float|null $postfilialeMaxWeight Maximum weight for Parcelshop delivery.
	 *
	 * @return self
	 */
	public function setPostfilialeMaxWeight( $postfilialeMaxWeight ) {
		$this->postfilialeMaxWeight = $postfilialeMaxWeight;

		return $this;
	}

	/**
	 * Get maximum width for Parcelshop delivery.
	 *
	 * @return int|null
	 */
	public function getPostfilialeMaxWidth() {
		return $this->postfilialeMaxWidth;
	}

	/**
	 * Set maximum width for Parcelshop delivery.
	 *
	 * @param int|null $postfilialeMaxWidth Maximum width for Parcelshop delivery.
	 *
	 * @return self
	 */
	public function setPostfilialeMaxWidth( $postfilialeMaxWidth ) {
		$this->postfilialeMaxWidth = $postfilialeMaxWidth;

		return $this;
	}

	/**
	 * Get maximum height for Parcelshop delivery.
	 *
	 * @return int|null
	 */
	public function getPostfilialeMaxHeight() {
		return $this->postfilialeMaxHeight;
	}

	/**
	 * Set maximum height for Parcelshop delivery.
	 *
	 * @param int|null $postfilialeMaxHeight Maximum height for Parcelshop delivery.
	 *
	 * @return self
	 */
	public function setPostfilialeMaxHeight( $postfilialeMaxHeight ) {
		$this->postfilialeMaxHeight = $postfilialeMaxHeight;

		return $this;
	}

	/**
	 * Get availability of NST delivery to Parcelshop points.
	 *
	 * @return bool|null
	 */
	public function getPostfilialeNstAvailable() {
		return $this->postfilialeNstAvailable;
	}

	/**
	 * Set availability of NST delivery to Parcelshop points.
	 *
	 * @param bool|null $postfilialeNstAvailable Availability of NST delivery to Parcelshop points.
	 *
	 * @return self
	 */
	public function setPostfilialeNstAvailable( $postfilialeNstAvailable ) {
		$this->postfilialeNstAvailable = $postfilialeNstAvailable;

		return $this;
	}

	/**
	 * Get maximum length for Parcelshop delivery.
	 *
	 * @return int|null
	 */
	public function getPostfilialeMaxLength() {
		return $this->postfilialeMaxLength;
	}

	/**
	 * Set maximum length for Parcelshop delivery.
	 *
	 * @param int|null $postfilialeMaxLength Maximum length for Parcelshop delivery.
	 *
	 * @return self
	 */
	public function setPostfilialeMaxLength( $postfilialeMaxLength ) {
		$this->postfilialeMaxLength = $postfilialeMaxLength;

		return $this;
	}

	/**
	 * Get postal code format.
	 *
	 * @return string|null
	 */
	public function getZipFormat() {
		return $this->zipFormat;
	}

	/**
	 * Set postal code format.
	 *
	 * @param string|null $zipFormat Postal code format.
	 *
	 * @return self
	 */
	public function setZipFormat( $zipFormat ) {
		$this->zipFormat = $zipFormat;

		return $this;
	}
}
