<?php
/**
 * Class ReturnService
 *
 * @package ILabs\WoocommerceDHL24
 */

namespace ILabs\WoocommerceDHL24\DHL24Client\WebAPI\Type;

/**
 * ReturnService
 */
class ReturnService {
	/**
	 * Special service type.
	 *
	 * @var string|null
	 */
	private $serviceType;

	/**
	 * Declared value required when ordering the insurance service.
	 *
	 * @var float|null
	 */
	private $serviceValue;

	/**
	 * Return associative array.
	 *
	 * @return array
	 */
	public function toArray(): array {
		return array(
			'serviceType'  => $this->getServiceType(),
			'serviceValue' => $this->getServiceValue(),
		);
	}


	/**
	 * Get special service type.
	 *
	 * @return string|null
	 */
	public function getServiceType() {
		return $this->serviceType;
	}

	/**
	 * Set special service type.
	 * Possible values:
	 * INSUR - Shipment insurance - only for domestic shipments, additional fees apply
	 *
	 * @param string|null $serviceType Special service type.
	 *
	 * @return self
	 */
	public function setServiceType( $serviceType ) {
		$this->serviceType = $serviceType;

		return $this;
	}

	/**
	 * Get declared value required when ordering the insurance service.
	 *
	 * @return float|null
	 */
	public function getServiceValue() {
		return $this->serviceValue;
	}

	/**
	 * Set declared value required when ordering the insurance service.
	 *
	 * @param float|null $serviceValue Declared value required when ordering the insurance service.
	 *
	 * @return self
	 */
	public function setServiceValue( $serviceValue ) {
		$this->serviceValue = $serviceValue;

		return $this;
	}
}
