<?php
/**
 * Class Shipment
 *
 * @package ILabs\WoocommerceDHL24
 */

namespace ILabs\WoocommerceDHL24\DHL24Client\WebAPI\Type;

use ILabs\WoocommerceDHL24\DHL24Client\ResultInterface;

/**
 * Shipment
 */
class Shipment implements ResultInterface {
	/**
	 * Parcel ID.
	 *
	 * @var string|null
	 */
	private $shipmentNotificationNumber;

	/**
	 * Shipment tracking number.
	 *
	 * @var string|null
	 */
	private $shipmentTrackingNumber;

	/**
	 * Packages tracking number.
	 *
	 * @var string|null
	 */
	private $packagesTrackingNumbers;

	/**
	 * Order ID (if courier is booked).
	 *
	 * @var string|null
	 */
	private $dispatchNotificationNumber;

	/**
	 * Label.
	 *
	 * @var Label|null
	 */
	private $label;

	/**
	 * Get parcel ID.
	 *
	 * @return string|null
	 */
	public function getShipmentNotificationNumber() {
		return $this->shipmentNotificationNumber;
	}

	/**
	 * Set parcel ID.
	 *
	 * @param string|null $shipmentNotificationNumber Parcel ID.
	 *
	 * @return self
	 */
	public function setShipmentNotificationNumber( $shipmentNotificationNumber ) {
		$this->shipmentNotificationNumber = $shipmentNotificationNumber;

		return $this;
	}

	/**
	 * Get shipment tracking number.
	 *
	 * @return string|null
	 */
	public function getShipmentTrackingNumber() {
		return $this->shipmentTrackingNumber;
	}

	/**
	 * Set shipment tracking number.
	 *
	 * @param string|null $shipmentTrackingNumber Shipment tracking number.
	 *
	 * @return self
	 */
	public function setShipmentTrackingNumber( $shipmentTrackingNumber ) {
		$this->shipmentTrackingNumber = $shipmentTrackingNumber;

		return $this;
	}

	/**
	 * Get packages tracking number.
	 *
	 * @return string|null
	 */
	public function getPackagesTrackingNumbers() {
		return $this->packagesTrackingNumbers;
	}

	/**
	 * Set packages tracking number.
	 *
	 * @param string|null $packagesTrackingNumbers Packages tracking number.
	 *
	 * @return self
	 */
	public function setPackagesTrackingNumbers( $packagesTrackingNumbers ) {
		$this->packagesTrackingNumbers = $packagesTrackingNumbers;

		return $this;
	}

	/**
	 * Get order ID (if courier is booked).
	 *
	 * @return string|null
	 */
	public function getDispatchNotificationNumber() {
		return $this->dispatchNotificationNumber;
	}

	/**
	 * Set order ID (if courier is booked).
	 *
	 * @param string|null $dispatchNotificationNumber Order ID (if courier is booked).
	 *
	 * @return self
	 */
	public function setDispatchNotificationNumber( $dispatchNotificationNumber ) {
		$this->dispatchNotificationNumber = $dispatchNotificationNumber;

		return $this;
	}

	/**
	 * Get label.
	 *
	 * @return Label|null
	 */
	public function getLabel() {
		return $this->label;
	}

	/**
	 * Set label.
	 *
	 * @param Label|null $label Label.
	 *
	 * @return self
	 */
	public function setLabel( $label ) {
		$this->label = $label;

		return $this;
	}
}
