<?php
/**
 * Class ShipmentTime
 *
 * @package ILabs\WoocommerceDHL24
 */

namespace ILabs\WoocommerceDHL24\DHL24Client\WebAPI\Type;

/**
 * ShipmentTime
 */
class ShipmentTime {
	/**
	 * Shipment time.
	 *
	 * @var \DateTime
	 */
	private $shipmentDate;

	/**
	 * Beginning of the time range when a courier can collect the shipment; in HH:MM format.
	 *
	 * @var string|null
	 */
	private $shipmentStartHour;

	/**
	 * End of the time range when a courier can collect the shipment; in HH:MM format.
	 *
	 * @var string|null
	 */
	private $shipmentEndHour;

	/**
	 * Constructor
	 */
	public function __construct() {
		$this->shipmentDate = new \DateTime( 'tomorrow' );
	}

	/**
	 * Return associative array.
	 *
	 * @return array
	 */
	public function toArray(): array {
		return array(
			'shipmentDate'      => $this->getShipmentDate()->format( 'Y-m-d' ), // Date in YYYY-MM-DD format.
			'shipmentStartHour' => $this->getShipmentStartHour(),
			'shipmentEndHour'   => $this->getShipmentEndHour(),
		);
	}

	/**
	 * Get shipment time.
	 *
	 * @return \DateTime
	 */
	public function getShipmentDate() {
		return $this->shipmentDate;
	}

	/**
	 * Set shipment time.
	 *
	 * @param \DateTime $shipmentDate Shipment time.
	 *
	 * @return self
	 */
	public function setShipmentDate( \DateTime $shipmentDate ) {
		$this->shipmentDate = $shipmentDate;

		return $this;
	}

	/**
	 * Get beginning of the time range when a courier can collect the shipment; in HH:MM format.
	 *
	 * @return string|null
	 */
	public function getShipmentStartHour() {
		return $this->shipmentStartHour;
	}

	/**
	 * Set beginning of the time range when a courier can collect the shipment; in HH:MM format.
	 *
	 * @param string|null $shipmentStartHour Beginning of the time range when a courier can collect the shipment; in HH:MM format.
	 *
	 * @return self
	 */
	public function setShipmentStartHour( $shipmentStartHour ) {
		$this->shipmentStartHour = $shipmentStartHour;

		return $this;
	}

	/**
	 * Get end of the time range when a courier can collect the shipment; in HH:MM format.
	 *
	 * @return string|null
	 */
	public function getShipmentEndHour() {
		return $this->shipmentEndHour;
	}

	/**
	 * Set end of the time range when a courier can collect the shipment; in HH:MM format.
	 *
	 * @param string|null $shipmentEndHour End of the time range when a courier can collect the shipment; in HH:MM format.
	 *
	 * @return self
	 */
	public function setShipmentEndHour( $shipmentEndHour ) {
		$this->shipmentEndHour = $shipmentEndHour;

		return $this;
	}
}
