<?php
/**
 * Class ShipmentTimeLabel
 *
 * @package ILabs\WoocommerceDHL24
 */

namespace ILabs\WoocommerceDHL24\DHL24Client\WebAPI\Type;

/**
 * ShipmentTimeLabel
 */
class ShipmentTimeLabel {
	/**
	 * Label expiry date.
	 *
	 * @var string|null
	 */
	private $labelExpDate;

	/**
	 * Shipment time in YYYY-MM-DD format.
	 *
	 * @var string|null
	 */
	private $shipmentDate;

	/**
	 * Beginning of the time range when a courier can collect the shipment; in HH:MM format.
	 *
	 * @var string|null
	 */
	private $shipmentStartHour;

	/**
	 * End of the time range when a courier can collect the shipment; in HH:MM format.
	 *
	 * @var string|null
	 */
	private $shipmentEndHour;

	/**
	 * Get label expiry date.
	 *
	 * @return string|null
	 */
	public function getLabelExpDate() {
		return $this->labelExpDate;
	}

	/**
	 * Set label expiry date.
	 *
	 * @param string|null $labelExpDate Label expiry date.
	 *
	 * @return self
	 */
	public function setLabelExpDate( $labelExpDate ) {
		$this->labelExpDate = $labelExpDate;

		return $this;
	}

	/**
	 * Get shipment time in YYYY-MM-DD format.
	 *
	 * @return string|null
	 */
	public function getShipmentDate() {
		return $this->shipmentDate;
	}

	/**
	 * Set shipment time in YYYY-MM-DD format.
	 *
	 * @param string|null $shipmentDate Shipment time in YYYY-MM-DD format.
	 *
	 * @return self
	 */
	public function setShipmentDate( $shipmentDate ) {
		$this->shipmentDate = $shipmentDate;

		return $this;
	}

	/**
	 * Get beginning of the time range when a courier can collect the shipment; in HH:MM format.
	 *
	 * @return string|null
	 */
	public function getShipmentStartHour() {
		return $this->shipmentStartHour;
	}

	/**
	 * Set beginning of the time range when a courier can collect the shipment; in HH:MM format.
	 *
	 * @param string|null $shipmentStartHour Beginning of the time range when a courier can collect the shipment; in HH:MM format.
	 *
	 * @return self
	 */
	public function setShipmentStartHour( $shipmentStartHour ) {
		$this->shipmentStartHour = $shipmentStartHour;

		return $this;
	}

	/**
	 * Get end of the time range when a courier can collect the shipment; in HH:MM format.
	 *
	 * @return string|null
	 */
	public function getShipmentEndHour() {
		return $this->shipmentEndHour;
	}

	/**
	 * Set end of the time range when a courier can collect the shipment; in HH:MM format.
	 *
	 * @param string|null $shipmentEndHour End of the time range when a courier can collect the shipment; in HH:MM format.
	 *
	 * @return self
	 */
	public function setShipmentEndHour( $shipmentEndHour ) {
		$this->shipmentEndHour = $shipmentEndHour;

		return $this;
	}
}
