<?php
/**
 * Class TrackAndTrace
 *
 * @package ILabs\WoocommerceDHL24
 */

namespace ILabs\WoocommerceDHL24\DHL24Client\WebAPI\Type;

use ILabs\WoocommerceDHL24\DHL24Client\ResultInterface;

/**
 * TrackAndTrace
 */
class TrackAndTrace implements ResultInterface {
	/**
	 * Shipment ID number.
	 *
	 * @var string
	 */
	private $shipmentId;

	/**
	 * Information on the person who claimed the parcel (if it has already been delivered).
	 *
	 * @var string|null
	 */
	private $receivedBy;

	/**
	 * Array of TrackAndTraceEvent.
	 *
	 * @var \ArrayObject|TrackAndTraceEvent[]
	 */
	private $events;

	/**
	 * Construct
	 *
	 * @return void
	 */
	public function __construct() {
		$this->events = new \ArrayObject();
		$this->shipmentId = '';
	}

	/**
	 * Get shipment ID number.
	 *
	 * @return string
	 */
	public function getShipmentId(): string {
		return $this->shipmentId;
	}

	/**
	 * Set shipment ID number.
	 *
	 * @param string $shipmentId Shipment ID number.
	 *
	 * @return self
	 */
	public function setShipmentId( string $shipmentId ) {
		$this->shipmentId = $shipmentId;

		return $this;
	}

	/**
	 * Get information on the person who claimed the parcel (if it has already been delivered).
	 *
	 * @return string|null
	 */
	public function getReceivedBy() {
		return $this->receivedBy;
	}

	/**
	 * Set information on the person who claimed the parcel (if it has already been delivered).
	 *
	 * @param string|null $receivedBy Information on the person who claimed the parcel (if it has already been delivered).
	 *
	 * @return self
	 */
	public function setReceivedBy( $receivedBy ) {
		$this->receivedBy = $receivedBy;

		return $this;
	}

	/**
	 * Get array of TrackAndTraceEvent.
	 *
	 * @return \ArrayObject|TrackAndTraceEvent[]
	 */
	public function getEvents() {
		return $this->events;
	}

	/**
	 * Add TrackAndTraceEvent.
	 *
	 * @param TrackAndTraceEvent $trackAndTraceEvent TrackAndTraceEvent.
	 *
	 * @return self
	 */
	public function addEvent( TrackAndTraceEvent $trackAndTraceEvent ) {
		$this->events->append( $trackAndTraceEvent );

		return $this;
	}

	/**
	 * Remove TrackAndTraceEvent.
	 *
	 * @param TrackAndTraceEvent $trackAndTraceEvent TrackAndTraceEvent.
	 *
	 * @return self
	 */
	public function removeEvent( TrackAndTraceEvent $trackAndTraceEvent ) {
		// TODO.

		return $this;
	}
}
