<?php
/**
 * Class Formatter.
 *
 * @package ILabs\WoocommerceDHL24
 */

namespace ILabs\WoocommerceDHL24\Helper;

/**
 * Formatter
 */
class Formatter {

	/**
	 * Post code
	 *
	 * @param  string $post_code Post code.
	 * @param  string $country Country code.
	 * @return string
	 */
	public function post_code( string $post_code, string $country = 'PL' ): string {
		/**
		 * Nie wiem czy to kwestia ustawień koszyka czy wtyczki, ale np. do Holandii kod pocztowy
		 * zawiera 4 cyfry i 2 litery. Po wpisaniu kodu ciągiem 1234ab do zamówienia dodała się
		 * spacja 1234 ab przez co API zwróciło błąd i musiałem poprawiać kod.
		 */
		$post_code = str_replace( ' ', '', $post_code );
		/**
		 * Nie można nadać paczki do Portugalii, tylko dla tego kraju wymagane jest przekazanie
		 * kodu pocztowego z kreską xxxx-xxx przez API wysyłane są tylko cyfry kodu.
		 */
		if ( 'PT' === $country ) {
			return $post_code;
		}
		return str_replace( '-', '', $post_code );
	}

	/**
	 * Street
	 *
	 * @param  string $value House number and street name.
	 * @return array
	 */
	public function street( string $value ): array {
		$result = array(
			'street'       => '',
			'house_number' => '.',
		);
		$value  = trim( $value );
		$p      = strrpos( $value, ' ' );
		if ( false !== $p ) {
			$result['street']       = substr( $value, 0, $p );
			$result['house_number'] = substr( $value, $p + 1 );
		} else {
			$result['street'] = $value;
		}

		return $result;
	}
}
