<?php
/**
 * Class Option.
 *
 * @package ILabs\WoocommerceDHL24
 */

namespace ILabs\WoocommerceDHL24\Helper;

/**
 * Option
 */
class Option {

	/**
	 * Instance
	 *
	 * @var self|null
	 */
	private static $instance = null;

	/**
	 * Data
	 *
	 * @var array
	 */
	private $data;


	/**
	 * Construct
	 *
	 * @return void
	 */
	private function __construct() {
		// Fetch existing options.
		$options = get_option( Defaults::OPTION_NAME );
		$this->data = shortcode_atts( Defaults::get_values(), $options );
		$this->data['webapi_password'] = $options['webapi_password'] ? $options['webapi_password'] : '';
		$this->data['servicepoint_password'] = $options['servicepoint_password'] ? $options['servicepoint_password'] : '';
	}

	/**
	 * Get instance
	 *
	 * @return self
	 */
	public static function get_instance(): self {
		if ( null === self::$instance ) {
			self::$instance = new self();
		}

		return self::$instance;
	}


	/**
	 * Get data
	 *
	 * @return  array
	 */
	public function get_data(): array {
		return $this->data;
	}

	/**
	 * Get value of option name
	 *
	 * @param  string $option_name Option name.
	 * @return string
	 */
	public function get_value( string $option_name ): string {
		if ( isset( $this->data[ $option_name ] ) ) {
			return $this->data[ $option_name ];
		}

		return '';
	}
}
