<?php
/**
 * My parcels
 *
 * @package ILabs\WoocommerceDHL24
 *
 * @var array $args {
 *   Array of arguments.
 *   @type ShipmentBasicDatas my_shipments
 *   @type int                my_shipments_count
 *   @type int                my_shipments_show
 *   @type LabelsDatas        labels
 * }
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
} // Exit if accessed directly

do_action( 'dhl24_notices' );

$view = new \ILabs\WoocommerceDHL24\Helper\View();
$view->set_labels( $args['labels']->getItems() );
?>
<div class="wrap">
	<h1 class="wp-heading-inline"><?php esc_html_e( 'My parcels', 'woocommerce-dhl24' ); ?></h1>
	<hr class="wp-header-end">
	<h2 class='screen-reader-text'><?php esc_html_e( 'Filtering the parcel list', 'woocommerce-dhl24' ); ?></h2>
	<ul class='subsubsub'>
		<li class='all'><a class="current"><?php esc_html_e( 'All', 'woocommerce-dhl24' ); ?> <span class="count">(<?php echo esc_html( $args['my_shipments_count'] ); ?>)</span></a> |</li>
		<li class='show'><a><?php esc_html_e( 'Show', 'woocommerce-dhl24' ); ?> <span class="count">(<?php echo esc_html( $args['my_shipments_show'] ); ?>)</span></a></li>
	</ul>
	<form id="shipments-filter" method="get">
		<input type="hidden" name="page" value="<?php echo esc_attr( $view->get_page() ); ?>">
		<input type="hidden" name="path" value="<?php echo esc_attr( '/my_parcels' ); ?>">
		<?php wp_nonce_field( 'my_parcels_filter', '_wpnonce', false ); ?>
		<div class="tablenav top">
			<div class="alignleft actions bulkactions">
				<label for="bulk-action-selector-top" class="screen-reader-text"><?php esc_html_e( 'Select bulk action', 'woocommerce-dhl24' ); ?></label>
				<select name="action" id="bulk-action-selector-top">
					<option value="-1"><?php esc_html_e( 'Bulk actions', 'woocommerce-dhl24' ); ?></option>
					<option value="order_courier"><?php esc_html_e( 'Order courier delivery', 'woocommerce-dhl24' ); ?></option>
				</select>
				<input type="submit" id="doaction" class="button action" value="<?php esc_attr_e( 'Apply', 'woocommerce-dhl24' ); ?>">
			</div>
			<div class="alignleft actions">
				<label for="filter-by-date" class="screen-reader-text">Filtruj po dacie</label>
				<input id="dhl24_from" type="text" name="from" value="<?php echo esc_attr( $args['from'] ); ?>">
				<input id="dhl24_to" type="text" name="to" value="<?php echo esc_attr( $args['to'] ); ?>">
				<input type="submit" name="filter_action" id="post-query-submit" class="button" value="Przefiltruj">
			</div>
			<?php $view->parcels_pagination( 'top', $args['my_shipments_count'], $args['paged'] ); ?>
			<br class="clear">
		</div>
		<h2 class='screen-reader-text'><?php esc_html_e( 'Parcels list', 'woocommerce-dhl24' ); ?></h2>
		<table class="wp-list-table widefat fixed striped table-view-list">
			<thead>
				<tr>
					<td id='cb' class='column-cb check-column'><label class="screen-reader-text" for="cb-select-all-1"><?php esc_html_e( 'Choose all', 'woocommerce-dhl24' ); ?></label><input id="cb-select-all-1" type="checkbox" /></td>
					<th scope="col"><?php esc_html_e( 'Creation date', 'woocommerce-dhl24' ); ?></th>
					<th scope="col"><?php esc_html_e( 'Posting date', 'woocommerce-dhl24' ); ?></th>
					<th scope="col"><?php esc_html_e( 'Order/shipment number', 'woocommerce-dhl24' ); ?></th>
					<th scope="col"><?php esc_html_e( 'Recipient', 'woocommerce-dhl24' ); ?></th>
					<th scope="col"><?php esc_html_e( 'Sender', 'woocommerce-dhl24' ); ?></th>
					<th scope="col"><?php esc_html_e( 'Options', 'woocommerce-dhl24' ); ?></th>
				</tr>
			</thead>
			<tbody id="the-list">
				<?php if ( 0 === $args['my_shipments_show'] ) : ?>
					<tr class="no-items">
						<td class="colspanchange" colspan="7"><?php esc_html_e( 'No parcels were found.', 'woocommerce-dhl24' ); ?></td>
					</tr>
				<?php else : ?>
					<?php
					/**
					 * Loop
					 *
					 * @var \ILabs\WoocommerceDHL24\DHL24Client\WebAPI\Type\ShipmentBasicData $item ShipmentBasicData
					 */
					foreach ( $args['my_shipments']->getShipments() as $item ) :
						$shipment_id      = esc_html( $item->getShipmentId() );
						$courier_order_id = '';
						$is_sp_label      = false;
						foreach ( $args['labels']->getItems() as $label ) {
							if ( $label->getShipmentId() === $shipment_id ) {
								if ( null !== $label->getDispatchNotificationNumber() ) {
									$courier_order_id = $label->getDispatchNotificationNumber();
								}
								$is_sp_label = null === $label->getServicepoint()->getServicePointAccountNumber() ? false : true;
								break;
							}
							if ( null !== $label->getService() && in_array( $label->getService()->getProduct(), array( 'EK', 'PI' ) ) ) {
								$find = false;
								foreach ( $label->getPieceList() as $piece ) {
									if ( $piece->getBlpPieceId() === $shipment_id ) {
										if ( null !== $label->getDispatchNotificationNumber() ) {
											$courier_order_id = $label->getDispatchNotificationNumber();
										}
										$find = true;
										break;
									}
								}
								if ( true === $find ) {
									break;
								}
							}
						}
						// phpcs:disable
						?>
					<tr id="shipment-<?php echo $shipment_id; ?>">
						<th scope="row" class="check-column">
							<label class="screen-reader-text" for="cb-select-1"><?php esc_html_e( 'Parcel', 'woocommerce-dhl24' ); echo ': ' . $shipment_id; ?></label>
							<input id="cb-select-1" type="checkbox" name="ids[]" value="<?php echo $shipment_id; ?>" />
						</th>
						<td><?php echo esc_html( $item->getCreated() ); ?></td>
						<td><?php echo esc_html( $view->get_shipment_date( $shipment_id ) ); ?></td>
						<td><?php echo $view->esc_order_number( $courier_order_id ); ?><br />
							<a href="<?php echo esc_url( add_query_arg( array( 'path' => '/shipment', 'id' => $shipment_id ) ) ); ?>"><?php echo $shipment_id; ?></a><br />
						</td>
						<td><?php echo $view->esc_address( $item->getReceiver() )?></td>
						<td><?php echo $view->esc_address( $item->getShipper() ) ?></td>
						<td>
							<a href="<?php echo esc_url( $view->download_label_url( $shipment_id, 'lblp', $is_sp_label ) ); ?>">LBLP</a>
							|
							<a href="<?php echo esc_url( $view->download_label_url( $shipment_id, 'zblp', $is_sp_label ) ); ?>">ZBLP</a>
							|
							<a href="<?php echo esc_url( $view->download_label_url( $shipment_id, 'blp', $is_sp_label ) ); ?>">BLP</a>
							|
							<a href="<?php echo esc_url( $view->download_scan_url( $shipment_id) ); ?>"><?php esc_html_e( 'Scan', 'woocommerce-dhl24' ); ?></a>
							|
							<a href="<?php echo esc_url( add_query_arg( array( 'path' => '/shipment', 'id' => $shipment_id ) ) ); ?>"><?php esc_html_e( 'Show', 'woocommerce-dhl24' ); ?></a>
							|
							<?php if ( '' !== $courier_order_id ) : ?>
							<a href="<?php echo esc_url( add_query_arg( array( 'path' => '/cancel_courier_booking', 'id' => $courier_order_id ) ) ); ?>"><?php esc_html_e( 'Cancel courier booking', 'woocommerce-dhl24' ); ?></a>
							|
							<?php endif; ?>
							<a href="<?php echo esc_url( add_query_arg( array( 'path' => '/delete_shipment', 'id' => $shipment_id, 'co_id' => $courier_order_id ) ) ); ?>"><?php esc_html_e( 'Delete', 'woocommerce-dhl24' ); ?></a>
						</td>
					</tr>
					<?php // phpcs:enable ?>
					<?php endforeach; ?>
				<?php endif; ?>
			</tbody>
			<tfoot>
				<tr>
					<td id='cb' class='column-cb check-column'><label class="screen-reader-text" for="cb-select-all-2"><?php esc_html_e( 'Choose all', 'woocommerce-dhl24' ); ?></label><input id="cb-select-all-2" type="checkbox" /></td>
					<th scope="col"><?php esc_html_e( 'Creation date', 'woocommerce-dhl24' ); ?></th>
					<th scope="col"><?php esc_html_e( 'Posting date', 'woocommerce-dhl24' ); ?></th>
					<th scope="col"><?php esc_html_e( 'Order/shipment number', 'woocommerce-dhl24' ); ?></th>
					<th scope="col"><?php esc_html_e( 'Recipient', 'woocommerce-dhl24' ); ?></th>
					<th scope="col"><?php esc_html_e( 'Sender', 'woocommerce-dhl24' ); ?></th>
					<th scope="col"><?php esc_html_e( 'Options', 'woocommerce-dhl24' ); ?></th>
				</tr>
			</tfoot>

		</table>
		<div class="tablenav bottom">
			<div class="alignleft actions bulkactions">
				<label for="bulk-action-selector-bottom" class="screen-reader-text"><?php esc_html_e( 'Select bulk action', 'woocommerce-dhl24' ); ?></label>
				<select name="action" id="bulk-action-selector-bottom">
					<option value="-1"><?php esc_html_e( 'Bulk actions', 'woocommerce-dhl24' ); ?></option>
					<option value="order_courier"><?php esc_html_e( 'Order courier delivery', 'woocommerce-dhl24' ); ?></option>
				</select>
				<input type="submit" id="doaction" class="button action" value="<?php esc_attr_e( 'Apply', 'woocommerce-dhl24' ); ?>">
			</div>
			<?php $view->parcels_pagination( 'button', $args['my_shipments_count'], $args['paged'] ); ?>
			<br class="clear">
		</div>
	</form>
	<div class="clear"></div>
</div>
