<?php
/**
 * Create shipment
 *
 * @package ILabs\WoocommerceDHL24
 * @var array $args {
 *   Array of arguments.
 *   @type int      order_id
 *   @type WC_Order order
 *   @type string   shipping_method_id
 *   @type array    pickup_days
 *   @type bool     insurance
 *   @type string   insurance_value
 *   @type bool     collect_on_delivery
 *   @type string   collect_on_delivery_value
 * }
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
} // Exit if accessed directly

use ILabs\WoocommerceDHL24\Helper\Option;
use ILabs\WoocommerceDHL24\Helper\Param;
use ILabs\WoocommerceDHL24\Helper\Template;
use ILabs\WoocommerceDHL24\Helper\View;

do_action( 'dhl24_notices' );
if ( empty( $args ) ) {
	return;
}
/** Order @var WC_Order $wc_order */
$wc_order   = $args['order'];
$order_data = $wc_order->get_data();
$view       = new View();
$name       = $order_data['shipping']['company'];
if ( empty( $name ) ) {
	$name = $order_data['shipping']['first_name'] . ' ' . $order_data['shipping']['last_name'];
}
$servicepoint_shipping_methods  = Param::get_instance()->get_value( 'servicepoint_shipping_methods' );
$international_shipping_methods = Param::get_instance()->get_value( 'international_shipping_methods' );
$defaults_data                  = Option::get_instance()->get_data();
$templates                      = Template::get_instance()->get_templates();
?>
<div class="wrap">
	<h1 class="wp-heading-inline">
		<?php esc_html_e( 'New Shipment', 'woocommerce-dhl24' ); ?>
	</h1>
	<hr class="wp-header-end">
	<div class="clear"></div>
	<div class="container">
		<div class="row">
			<div class="col-6 info-col bl">
				<div class="info-col__text">
					<?php esc_html_e( 'Sender', 'woocommerce-dhl24' ); ?>:
				</div>
				<div class="info-col__title">
					<?php echo esc_html( Option::get_instance()->get_value( 'name' ) ); ?>
				</div>
				<div class="info-col__text">
					<?php echo $view->esc_company_address(); // phpcs:ignore?> <br>
				</div>
				<div class="info-col__text"><br />
					<?php esc_html_e( 'Payer', 'woocommerce-dhl24' ); ?>: <?php echo esc_html( Option::get_instance()->get_value( 'sap' ) ); ?><br />
					<?php esc_html_e( 'Payment form', 'woocommerce-dhl24' ); ?>: <?php echo esc_html( 'BANK' ); ?>
				</div>
			</div>
			<div class="col-6 info-col br">
				<div class="info-col__text">
					<?php esc_html_e( 'Recipient', 'woocommerce-dhl24' ); ?>:
				</div>
				<div class="info-col__title">
					<?php echo esc_html( $name ); ?>
				</div>
				<div class="info-col__text">
					<?php echo $view->esc_wp_shipping_address($order_data['shipping']); // phpcs:ignore?> <br />
					<?php echo esc_html( $order_data['shipping']['first_name'] . ' ' . $order_data['shipping']['last_name'] ); ?><br />
					<?php echo esc_html( $order_data['billing']['email'] ); ?>, <?php echo esc_html( $order_data['billing']['phone'] ); ?>
				</div>
			</div>
		</div>
		<div>
			<div class="row">
				<div class="col-12 info-col__title">
					<?php esc_html_e( 'Order details', 'woocommerce-dhl24' ); ?>
				</div>
			</div>
			<?php foreach ( $wc_order->get_items() as $item_id => $item ) : ?>
				<div class="row">
					<div class="col-4">
						<?php echo wp_kses_post( $item->get_name() ); ?>
					</div>
					<div class="col-1">
						<small class="times">&times;</small> <?php echo esc_html( $item->get_quantity() ); ?>
					</div>
					<div class="col-1 text-right">
						<?php echo wc_price( $item->get_total(), array( 'currency' => $wc_order->get_currency() ) ); // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped ?>
					</div>
				</div>
			<?php endforeach; ?>
			<div class="row mb-1">
				<div class="col-5 text-right">
					<?php esc_html_e( 'Total', 'woocommerce-dhl24' ); ?>:
				</div>
				<div class="col-1 text-right">
					<?php echo wc_price( $wc_order->get_total(), array( 'currency' => $wc_order->get_currency() ) ); // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped ?>
				</div>
			</div>
			<div class="row mb-1 bb">
				<div class="col-12">
					<p><?php printf( /* translators: %s: payment method */ esc_html__( 'Payment via %s', 'woocommerce-dhl24' ), esc_html( $wc_order->get_payment_method_title() ) ); ?></p>
				</div>
			</div>
		</div>
		<div class="row">
			<div class="col-12 info-col__title">
				<?php esc_html_e( 'Shipment details', 'woocommerce-dhl24' ); ?>
			</div>
		</div>
		<form action="#" onsubmit="return false;">
			<div class="row mb-1">
				<div class="col-2">
					<label for="dhl24_templates"><?php esc_html_e( 'Templates', 'woocommerce-dhl24' ); ?></label>
				</div>
				<div class="col-10">
					<select id="dhl24_templates">
						<option value=""><?php esc_html_e( 'Select template ...', 'woocommerce-dhl24' ); ?></option>
						<?php foreach ( $templates as $template ) : ?>
							<option value="<?php echo esc_attr( $template['id'] ); ?>" data-template="<?php echo esc_attr( wp_json_encode( $template ) ); ?>"><?php echo esc_html( $template['name'] ); ?></option>
						<?php endforeach; ?>
					</select>
				</div>
			</div>
		</form>
		<form id="dhl24-new-shipment" method="post" action="#" onsubmit="return false;">
			<div class="row">
				<input type="hidden" name="action" value="dhl24_new_shipment">
				<input type="hidden" name="new_shipment[_nonce]" value="<?php echo esc_attr( $args['_nonce'] ); ?>">
				<input type="hidden" name="new_shipment[order_id]" value="<?php echo esc_attr( $wc_order->get_id() ); ?>">
				<input type="hidden" name="new_shipment[shipping_method]" value="<?php echo esc_attr( $args['shipping_method_id'] ); ?>">
				<div class="col-12">
					<table class="dhl24-table-piece">
						<tbody id="dhl24-pieces" data-prototype="<?php echo esc_attr( $view->esc_add_piece_row( $args['shipping_method_id'], '__index__' ) ); ?>">
							<?php echo $view->esc_add_piece_row( $args['shipping_method_id'] ); // phpcs:ignore?>
						</tbody>
					</table>
				</div>
			</div>
			<div class="row">
				<div class="col-3">
					<input class="dhl24_content" type="text" name="new_shipment[content]" value="<?php echo esc_attr( $defaults_data['content'] ); ?>" placeholder="<?php esc_attr_e( 'Content', 'woocommerce-dhl24' ); ?>: *" required="required">
				</div>
				<div class="col-4">
					<input class="dhl24_comment" type="text" name="new_shipment[comment]" value="<?php echo esc_attr( $defaults_data['comment'] ); ?>" placeholder="<?php esc_attr_e( 'Notes', 'woocommerce-dhl24' ); ?>">
				</div>
				<div class="col-3">
					<input class="dhl24_reference" type="text" name="new_shipment[reference]" value="<?php echo esc_attr( $defaults_data['reference'] ); ?>" placeholder="<?php esc_attr_e( 'Reference', 'woocommerce-dhl24' ); ?>">
				</div>
				<div class="col-2">
					<input class="dhl24_costs_center" type="text" name="new_shipment[costs_center]" value="<?php echo esc_attr( $defaults_data['costs_center'] ); ?>" placeholder="<?php esc_attr_e( 'CC', 'woocommerce-dhl24' ); ?>">
				</div>
			</div>
			<div class="row">
				<div class="col-12 info-col__title">
					<?php esc_html_e( 'Date of posting', 'woocommerce-dhl24' ); ?>
				</div>
			</div>
			<div class="row">
				<div class="col-5">
					<h4><?php echo esc_html( $wc_order->get_shipping_method() ); ?></h4>
					<?php if ( in_array( $args['shipping_method_id'], $servicepoint_shipping_methods, true ) ) : ?>
					<h4><?php esc_html_e( 'Parcelshop details', 'woocommerce-dhl24' ); ?></h4>
					<div class="row">
						<div class="col-4">
						<?php esc_html_e( 'Service point SAP number', 'woocommerce-dhl24' ); ?>
						</div>
						<div class="col-8">
							<div class="form__field">
								<input type="text" name="new_shipment[sap]" value="<?php echo esc_attr( $wc_order->get_meta( 'dhl24_sap' ) ); ?>" disabled="disabled">
							</div>
						</div>
					</div>
					<?php endif; ?>
					<div class="form__field">
						<label for="dhl24_shipment_date" class="required"><?php esc_html_e( 'Date of posting', 'woocommerce-dhl24' ); ?> <span class="required">*</span></label>
						<select id="dhl24_shipment_date" name="new_shipment[shipment_date]" required="required">
							<?php foreach ( $args['pickup_days'] as $day ) : ?>
							<option value="<?php echo esc_attr( $day->format( 'Y-m-d' ) ); ?>"><?php echo esc_html( $day->format( 'Y-m-d' ) ); ?></option>
							<?php endforeach; ?>
						</select>
					</div>
				</div>
				<div class="col-7">
					<h4><?php esc_html_e( 'Select special services', 'woocommerce-dhl24' ); ?></h4>
					<div class="row">
						<div class="col-4">
							<div class="form__field">
								<input class="dhl24_service_insurance" type="checkbox" name="new_shipment[service][insurance]" value="1" id="service_insurance"
								<?php if ( true === $args['insurance'] ) : ?>
									checked="checked"
								<?php endif; ?> />
								<label for="service_insurance"><?php esc_html_e( 'Shipment insurance', 'woocommerce-dhl24' ); ?></label>
							</div>
						</div>
						<div class="col-8">
							<div class="form__field">
								<input class="dhl24_service_insurance_value" type="text" name="new_shipment[service][insuranceValue]" value="<?php echo esc_attr( $args['insurance_value'] ); ?>" placeholder="<?php esc_attr_e( 'Value', 'woocommerce-dhl24' ); ?>">
								<span><?php esc_html_e( 'PLN', 'woocommerce-dhl24' ); ?></span>
							</div>
						</div>
					</div>
					<div class="row">
						<div class="col-4">
							<div class="form__field">
								<input type="checkbox" name="new_shipment[service][collectOnDelivery]" value="1" id="service_collectOnDelivery"
								<?php if ( true === $args['collect_on_delivery'] ) : ?>
									checked="checked"
								<?php endif; ?> />
								<label for="service_collectOnDelivery"><?php esc_html_e( 'Cash on delivery', 'woocommerce-dhl24' ); ?></label>
							</div>
						</div>
						<div class="col-8">
							<div class="form__field">
								<input type="text" name="new_shipment[service][collectOnDeliveryValue]" value="<?php echo esc_attr( $args['collect_on_delivery_value'] ); ?>" placeholder="<?php esc_attr_e( 'Value', 'woocommerce-dhl24' ); ?>">
								<?php if ( in_array( $args['shipping_method_id'], $international_shipping_methods, true ) ) : ?>
								<span><?php esc_html_e( 'The currency of the recipient country', 'woocommerce-dhl24' ); ?></span>
								<?php else : ?>
								<span><?php esc_html_e( 'PLN', 'woocommerce-dhl24' ); ?></span>
								<?php endif; ?>
							</div>
						</div>
					</div>
					<?php if ( ! in_array( $args['shipping_method_id'], $servicepoint_shipping_methods, true ) ) : ?>
					<div class="row">
						<div class="col-4">
							<div class="form__field">
								<input class="dhl24_service_predeliveryInformation" type="checkbox" name="new_shipment[service][predeliveryInformation]" value="1" id="service_predeliveryInformation" /><label for="service_predeliveryInformation"><?php esc_html_e( 'PDI', 'woocommerce-dhl24' ); ?></label>
							</div>
						</div>
						<div class="col-8">
						</div>
					</div>
					<div class="row">
						<div class="col-4">
							<div class="form__field">
								<input type="checkbox" name="new_shipment[service][proofOfDelivery]" value="1" id="service_proofOfDelivery" /><label for="service_proofOfDelivery"><?php esc_html_e( 'POD', 'woocommerce-dhl24' ); ?></label>
							</div>
						</div>
						<div class="col-8">
						</div>
					</div>
					<div class="row">
						<div class="col-4">
							<div class="form__field">
								<input type="checkbox" name="new_shipment[service][returnOnDelivery]" value="1" id="service_returnOnDelivery" /><label for="service_returnOnDelivery"><?php esc_html_e( 'Return of documents', 'woocommerce-dhl24' ); ?></label>
							</div>
						</div>
						<div class="col-8">
							<div class="form__field">
								<input type="text" name="new_shipment[service][returnOnDeliveryReference]" value="" placeholder="<?php esc_attr_e( 'Document title', 'woocommerce-dhl24' ); ?>">
							</div>
						</div>
					</div>
					<div class="row">
						<div class="col-4">
							<div class="form__field">
								<input type="checkbox" name="new_shipment[service][selfCollect]" value="1" id="service_selfCollect" /><label for="service_selfCollect"><?php esc_html_e( 'Self pickup', 'woocommerce-dhl24' ); ?></label>
							</div>
						</div>
						<div class="col-8">
						</div>
					</div>
					<div class="row">
						<div class="col-4">
							<div class="form__field">
								<input type="checkbox" name="new_shipment[service][deliveryOnSaturday]" value="1" id="service_deliveryOnSaturday" /><label for="service_deliveryOnSaturday"><?php esc_html_e( 'Saturday delivery', 'woocommerce-dhl24' ); ?></label>
							</div>
						</div>
						<div class="col-8">
						</div>
					</div>
					<?php endif ?>
				</div>
			</div>
			<div class="row">
				<div class="col-12 text-center pb-1 pt-1">
					<button class="button btn" type="submit"><?php esc_html_e( 'Save', 'woocommerce-dhl24' ); ?></button>
				</div>
			</div>
		</form>
	</div>
</div>
