<?php
/**
 * Shipment confirmation
 *
 * @package ILabs\WoocommerceDHL24
 *
 * @var array $args {
 *   Array of arguments.
 *   @type string              _nonce
 *   @type array               ids
 *   @type ShipperAddressLabel sender
 *   @type array               pickup_days
 *   @type array               available_hours
 *   @type array               piece_totals
 *   @type bool                is_dr_pickup
 * }
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
} // Exit if accessed directly
do_action( 'dhl24_notices' );
$view   = new \ILabs\WoocommerceDHL24\Helper\View();
$sender = $args['sender'];
?>
<div class="wrap">
	<h1 class="wp-heading-inline">
		<?php esc_html_e( 'Book a courier or drop off at our location', 'woocommerce-dhl24' ); ?>
	</h1>
	<hr class="wp-header-end">
	<div class="clear"></div>
	<div class="container">
		<div class="row">
			<div class="col-6 info-col bl">
				<div class="info-col__text">
					<?php esc_html_e( 'Sender\'s address details', 'woocommerce-dhl24' ); ?>
				</div>
				<div class="info-col__title"><?php echo esc_html( $sender->getName() ); ?></div>
				<div class="info-col__text">
				<?php echo $view->esc_sender_address( $sender ); // phpcs:ignore ?> <br>
				</div>
			</div>
			<div class="col-6 info-col br">
				<div class="info-col__text">
					<?php esc_html_e( 'Shipment details', 'woocommerce-dhl24' ); ?>
				</div>
				<?php foreach ( $args['piece_totals'] as $name => $quantity ) : ?>
					<?php if ( 0 < $quantity ) : ?>
				<div><?php echo $view->esc_parcel_quantity( $name, $quantity ); // phpcs:ignore ?></div>
					<?php endif; ?>
				<?php endforeach; ?>
			</div>
		</div>
		<form id="dhl24-order-courier" method="post" action="#" onsubmit="return false;">
			<input type="hidden" name="action" value="dhl24_order_courier">
			<input type="hidden" name="order_courier[_nonce]" value="<?php echo esc_attr( $args['_nonce'] ); ?>">
			<input type="hidden" name="order_courier[ids]" value="<?php echo esc_attr( implode( ',', $args['ids'] ) ); ?>">
			<div class="row">
				<div class="col-12 info-col__title">
					<?php esc_html_e( 'Courier collection', 'woocommerce-dhl24' ); ?>
				</div>
				<div class="col-6 info-col bl">
					<div class="info-col__text">
						<div class="form__field">
							<label for="dhl24_pickup_date" class="required"><?php esc_html_e( 'Arrival date', 'woocommerce-dhl24' ); ?> <span class="required">*</span></label>
							<select id="dhl24_pickup_date" name="order_courier[pickup_date]" data-dr-pickup="<?php echo esc_attr( $args['is_dr_pickup'] ? '1' : '0' ); ?>">
								<?php foreach ( $args['pickup_days'] as $day ) : ?>
								<option value="<?php echo esc_attr( $day->format( 'Y-m-d' ) ); ?>"><?php echo esc_html( $day->format( 'Y-m-d' ) ); ?></option>
								<?php endforeach; ?>
							</select>
						</div>
						<div class="form__field">
							<label for="dhl24_pickup_from" class="required"><?php esc_html_e( 'Hour from', 'woocommerce-dhl24' ); ?> <span class="required">*</span></label>
							<select id="dhl24_pickup_from" name="order_courier[from]">
								<?php
								$items_count = 0;
								$selected    = true;
								foreach ( $args['available_hours']['hours'] as $hour ) :
									if ( 0 < $items_count ) {
										$selected = false;
									}
									$items_count++;
									?>
									<option value="<?php echo esc_attr( $hour ); ?>"<?php echo $selected ? '  selected="selected"' : ''; ?>><?php echo esc_html( $hour ); ?></option>
								<?php endforeach; ?>
							</select>
						</div>
						<div class="form__field">
							<label for="dhl24_pickup_to" class="required"><?php esc_html_e( 'Hour to', 'woocommerce-dhl24' ); ?> <span class="required">*</span></label>
							<select id="dhl24_pickup_to" name="order_courier[to]">
								<?php
								$i        = 0;
								$selected = false;
								foreach ( $args['available_hours']['hours'] as $hour ) :
									$i++;
									if ( $i === $items_count ) {
										$selected = true;
									}
									?>
									<option value="<?php echo esc_attr( $hour ); ?>"<?php echo $selected ? '  selected="selected"' : ''; ?>><?php echo esc_html( $hour ); ?></option>
								<?php endforeach; ?>
							</select>
						</div>
					</div>
				</div>
				<div class="col-6 info-col br">
					<div class="form__field">
						<label for="dhl24_courier_comment"><?php esc_html_e( 'Comments for courier', 'woocommerce-dhl24' ); ?></label>
						<textarea id="dhl24_courier_comment" name="order_courier[comment]"></textarea>
					</div>
					<div class="form__checkboxes">
						<div class="form__field">
							<label for="dhl24_courier_label"><?php esc_html_e( 'I wish the courier to arrive with label printed out.', 'woocommerce-dhl24' ); ?></label>
							<input id="dhl24_courier_label" type="checkbox" name="order_courier[label]" value="1">
						</div>
					</div>
				</div>
			</div>
			<div class="row">
				<div class="col-12 text-center">
					<button class="button btn" type="submit"><?php esc_html_e( 'Book a courier', 'woocommerce-dhl24' ); ?></button>
				</div>
			</div>
		</form>
	</div>
</div>
<div>
	<div><a href="<?php echo esc_url( add_query_arg( 'path', '/my_parcels', $view->admin_url() ) ); ?>"><?php esc_html_e( 'Back to my parcels list', 'woocommerce-dhl24' ); ?></a></div>
</div>
