<?php
/**
 * Create shipment
 *
 * @package ILabs\WoocommerceDHL24
 * @var array $args {
 *   Array of arguments.
 *   @type string     _nonce
 *   @type LabelsData labels_data
 *   @type string     label_exp_date
 *   @
 * }
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
} // Exit if accessed directly

use ILabs\WoocommerceDHL24\Helper\View;
use ILabs\WoocommerceDHL24\Helper\Param;
use ILabs\WoocommerceDHL24\Helper\Option;
use ILabs\WoocommerceDHL24\DHL24Client\WebAPI\Type\LabelsData;

do_action( 'dhl24_notices' );
if ( empty( $args ) ) {
	return;
}
$view = new View();
/**
 * LabelsData
 *
 * @var LabelsData $labels_data
 */
$labels_data                    = $args['labels_data'];
$sender                         = $labels_data->getReceiver();
$service                        = $labels_data->getService();
$billing                        = $labels_data->getBilling();
$shipping_method_id             = 'dhl24_service_' . strtolower( $service->getProduct() );
$defaults_data                  = Option::get_instance()->get_data();
$international_shipping_methods = Param::get_instance()->get_value( 'international_shipping_methods' );
if ( in_array( $shipping_method_id, $international_shipping_methods, true ) ) {
	$shipping_method_id = 'dhl24_service_zc';
} else {
	$shipping_method_id = 'dhl24_service_zk';
}
?>
<div class="wrap">
	<h1 class="wp-heading-inline">
		<?php esc_html_e( 'Return shipment', 'woocommerce-dhl24' ); ?>
	</h1>
	<hr class="wp-header-end">
	<div class="clear"></div>
	<div class="container">
		<div class="row">
			<div class="col-6 info-col bl">
				<div class="info-col__text">
					<?php esc_html_e( 'Sender', 'woocommerce-dhl24' ); ?>:
				</div>
				<div class="info-col__title">
					<?php echo esc_html( $sender->getName() ); ?>
				</div>
				<div class="info-col__text">
				    <?php echo $view->esc_recipient_address( $sender, 'ZK' ); // phpcs:ignore ?>
				</div>
			</div>
			<div class="col-6 info-col br">
				<div class="info-col__text">
					<?php esc_html_e( 'Recipient', 'woocommerce-dhl24' ); ?>:
				</div>
				<div class="info-col__title">
					<?php echo esc_html( Option::get_instance()->get_value( 'name' ) ); ?>
				</div>
				<div class="info-col__text">
					<?php echo $view->esc_company_return_address(); // phpcs:ignore?> <br>
				</div>
				<div class="info-col__text"><br />
					<?php esc_html_e( 'Payer', 'woocommerce-dhl24' ); ?>: <?php echo esc_html( Option::get_instance()->get_value( 'return_sap' ) ); ?><br />
					<?php esc_html_e( 'Payment form', 'woocommerce-dhl24' ); ?>: <?php echo esc_html( 'BANK' ); ?>
				</div>
			</div>
		</div>
		<div class="row">
			<div class="col-12 info-col__title">
				<?php esc_html_e( 'Shipment details', 'woocommerce-dhl24' ); ?>
			</div>
		</div>
		<form id="dhl24-return-shipment" method="post" action="#" onsubmit="return false;">
			<input type="hidden" name="action" value="dhl24_return_shipment">
			<input type="hidden" name="return_shipment[_nonce]" value="<?php echo esc_attr( $args['_nonce'] ); ?>">
			<input type="hidden" name="return_shipment[shipment_id]" value="<?php echo esc_attr( $labels_data->getShipmentId() ); ?>">
			<input type="hidden" name="return_shipment[shipping_method]" value="<?php echo esc_attr( $shipping_method_id ); ?>">
			<div class="row">
				<div class="col-12">
					<table class="dhl24-table-piece">
						<tbody id="dhl24-pieces" data-prototype="<?php echo esc_attr( $view->esc_add_piece_row( $shipping_method_id, '__index__' ) ); ?>">
							<?php
							foreach ( $labels_data->getPieceList() as $key => $piece ) :
								$values = array(
									'piece_quantity'     => $piece->getQuantity(),
									'piece_weight'       => $piece->getWeight(),
									'piece_width'        => $piece->getWidth(),
									'piece_height'       => $piece->getHeight(),
									'piece_length'       => $piece->getLength(),
									'piece_type'         => $piece->getType(),
									'piece_non_standard' => $piece->getNonStandard(),
									'piece_euro_return'  => $piece->getEuroReturn(),
								);
								?>
							<?php echo $view->esc_add_piece_row( $shipping_method_id, $key, $values ); // phpcs:ignore?>
							<?php endforeach; ?>
						</tbody>
					</table>
				</div>
				<div class="col-3">
					<input class="dhl24_content" type="text" name="return_shipment[content]" value="<?php echo esc_attr( $labels_data->getContent() ); ?>" placeholder="<?php esc_attr_e( 'Content', 'woocommerce-dhl24' ); ?>: *" required="required">
				</div>
				<div class="col-4">
					<input class="dhl24_comment" type="text" name="return_shipment[comment]" value="<?php echo esc_attr( $labels_data->getComment() ); ?>" placeholder="<?php esc_attr_e( 'Notes', 'woocommerce-dhl24' ); ?>">
				</div>
				<div class="col-3">
					<input class="dhl24_reference" type="text" name="return_shipment[reference]" value="<?php echo esc_attr( $labels_data->getReference() ); ?>" placeholder="<?php esc_attr_e( 'Reference', 'woocommerce-dhl24' ); ?>">
				</div>
				<div class="col-2">
					<input class="dhl24_costs_center" type="text" name="return_shipment[costs_center]" value="<?php echo esc_attr( $billing->getCostsCenter() ); ?>" placeholder="<?php esc_attr_e( 'CC', 'woocommerce-dhl24' ); ?>">
				</div>
				<div class="col-12 info-col__title">
					<?php esc_html_e( 'Delivery', 'woocommerce-dhl24' ); ?>
				</div>
				<div class="col-5">
					<div class="form__field">
						<label for="dhl24_label_exp_date" class="required"><?php esc_html_e( 'Label expiry date (only for the domestic return label)', 'woocommerce-dhl24' ); ?> <span class="required">*</span></label>
						<input id="dhl24_label_exp_date" type="text" name="return_shipment[label_exp_date]" value="<?php echo esc_attr( $args['label_exp_date'] ); ?>" required="required">
					</div>
					<?php if ( 'dhl24_service_zk' === $shipping_method_id ) : ?>
					<div class="form__field">
						<input type="checkbox" name="return_shipment[book_courier]" value="1" id="book_courier"
						<?php if ( 'yes' === $defaults_data['return_order_courier'] ) : ?>
							checked="checked"
						<?php endif; ?>
						/><label for="book_courier"><?php esc_html_e( 'The possibility of sending a return shipment by courier', 'woocommerce-dhl24' ); ?></label>
					</div>
					<?php endif ?>
				</div>
				<div class="col-7">
					<h4><?php esc_html_e( 'Select special services', 'woocommerce-dhl24' ); ?></h4>
					<div class="row">
						<div class="col-4">
							<div class="form__field">
								<input type="checkbox" name="return_shipment[service][insurance]" value="1" id="service_insurance"
								<?php if ( true === $service->getInsurance() ) : ?>
									checked="checked"
								<?php endif; ?>
								/><label for="service_insurance"><?php esc_html_e( 'Shipment insurance', 'woocommerce-dhl24' ); ?></label>
							</div>
						</div>
						<div class="col-8">
							<div class="form__field">
								<input type="text" name="return_shipment[service][insuranceValue]" value="<?php echo esc_attr( $service->getInsuranceValue() ); ?>" placeholder="<?php esc_attr_e( 'Value', 'woocommerce-dhl24' ); ?>">
								<span><?php esc_html_e( 'PLN', 'woocommerce-dhl24' ); ?></span>
							</div>
						</div>
					</div>
				</div>
				<div class="col-12 text-center pb-1 pt-1">
					<button class="button btn" type="submit"><?php esc_html_e( 'Save', 'woocommerce-dhl24' ); ?></button>
				</div>
			</div>
		</form>
	</div>
</div>
